import Foundation
import ITWebAPI
// MARK: Factory
open class BikebhtWebAPIContext : ITWebAPIContext{
	required public init(){}
    open var visitablePair:ITVisitablePair = ITXmlVisitablePair()
    fileprivate var secureKeys = [String:ITSecureKey]()
    open func setSecureKey(_ secureKey:ITSecureKey?) -> ITWebAPIContext?{
        if let secureKey_ = secureKey {
            secureKeys[secureKey_.name] = secureKey_
        }
        return self
    }

    open func getSecureKey(_ keyName:String) -> ITSecureKey? {
        return self.secureKeys[keyName]
    }

    open func getSecureKeys() -> [String:ITSecureKey]? {
        return self.secureKeys
    }

    open func createRequestBody(_ requestMapping:String) -> ITWebAPIBody {
        return self.createBody(type: .requestBody, requestMapping: requestMapping, content: nil, secureKeys: self.secureKeys)
    }
    open func createRequestBody(_ requestMapping:String,content:String?) -> ITWebAPIBody {
        return self.createBody(type: .requestBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
    }
    open func createRequestBody(_ requestMapping:String,content:String?,secureKey:ITSecureKey?) -> ITWebAPIBody{
        if secureKey == nil {
            return self.createBody(type: .requestBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
        }

        return self.createBody(type: .requestBody, requestMapping: requestMapping, content: content, secureKeys: [secureKey!.name:secureKey!])
    }

    open func createResponseBody(_ requestMapping:String) -> ITWebAPIBody {
        return self.createBody(type: .responseBody, requestMapping: requestMapping, content: nil, secureKeys: self.secureKeys)
    }
    open func createResponseBody(_ requestMapping:String,content:String?) -> ITWebAPIBody {
        return self.createBody(type: .responseBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
    }
    open func createResponseBody(_ requestMapping:String,content:String?,secureKey:ITSecureKey?) -> ITWebAPIBody {
        if secureKey == nil {
            return self.createBody(type: .responseBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
        }

        return self.createBody(type: .responseBody, requestMapping: requestMapping, content: content, secureKeys: [secureKey!.name:secureKey!])
    }

    fileprivate enum BodyType{
        case requestBody
        case responseBody
    }

    fileprivate func createBody(type:BodyType,requestMapping:String,content:String?,secureKeys:[String:ITSecureKey]) -> ITWebAPIBody{
        var body:ITWebAPIBody
        switch(requestMapping){
        				case "/api/bikebht/business/bhtrequest":
				if type == .requestBody {
                    body = BikebhtPostBhtRequest()
                } else {
                    body = BikebhtRetBhtRequest(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikebht/device/bhttrip":
				if type == .requestBody {
                    body = BikebhtPostBHTTrip()
                } else {
                    body = BikebhtRetBHTTrip(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikebht/business/bhtquerydevices":
				if type == .requestBody {
                    body = BikebhtPostBHTQueryDevices()
                } else {
                    body = BikebhtRetBHTQueryDevices(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikebht/device/firmwareupdate":
				if type == .requestBody {
                    body = BikebhtPostFirmwareUpdate()
                } else {
                    body = BikebhtRetFirmwareUpdate(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikebht/device/devlifecycle":
				if type == .requestBody {
                    body = BikebhtPostDevLifecycle()
                } else {
                    body = BikebhtRetDevLifecycle(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikebht/device/getbhtlock":
				if type == .requestBody {
                    body = BikebhtPostBhtDevBasicInfo()
                } else {
                    body = BikebhtRetBhtDevBasicInfo(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikebht/device/deletebhtdev":
				if type == .requestBody {
                    body = BikebhtPostDelDevBasicInfo()
                } else {
                    body = BikebhtRetDelDevBasicInfo(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikebht/device/getbhtloc":
				if type == .requestBody {
                    body = BikebhtPostDevLocInfo()
                } else {
                    body = BikebhtRetDevLocInfo(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikebht/device/getbhtlocklist":
				if type == .requestBody {
                    body = BikebhtPostBhtLockInfoList()
                } else {
                    body = BikebhtRetBhtLockInfoList(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikebht/device/devAuth":
				if type == .requestBody {
                    body = BikebhtPostDevAuth()
                } else {
                    body = BikebhtRetDevAuth(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikebht/device/queryDevAuthList":
				if type == .requestBody {
                    body = BikebhtPostQueryDevAuthList()
                } else {
                    body = BikebhtRetQueryDevAuthList(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikebht/device/updateDevAuth":
				if type == .requestBody {
                    body = BikebhtPostUpdateDevAuth()
                } else {
                    body = BikebhtRetUpdateDevAuth(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikebht/device/getbhtlockinfotoopera":
				if type == .requestBody {
                    body = BikebhtPostBhtLockInfoToOpera()
                } else {
                    body = BikebhtRetBhtLockInfoToOpera(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikebht/device/getbhtlockinfo":
				if type == .requestBody {
                    body = BikebhtPostBhtLockInfo()
                } else {
                    body = BikebhtRetBhtLockInfo(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikebht/device/getbhtlockinfoApp":
				if type == .requestBody {
                    body = BikebhtPostBhtLockInfoApp()
                } else {
                    body = BikebhtRetBhtLockInfoApp(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikebht/device/citycodeinfo":
				if type == .requestBody {
                    body = BikebhtPostCitycodeInfo()
                } else {
                    body = BikebhtRetCitycodeInfo(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikebht/device/stationInfoCollect":
				if type == .requestBody {
                    body = BikebhtPostStationInfoCollect()
                } else {
                    body = BikebhtRetStationInfoCollect(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikegw/manage/requestMgr":
				if type == .requestBody {
                    body = BikebhtPostManageRequest()
                } else {
                    body = BikebhtRetManageRequest(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikegw/manage/getVhclsMgr":
				if type == .requestBody {
                    body = BikebhtPostManageGetVhcls()
                } else {
                    body = BikebhtRetManageGetVhcls(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikegw/manage/iotRegistDevice":
				if type == .requestBody {
                    body = BikebhtPostIotRegistDevice()
                } else {
                    body = BikebhtRetIotRegistDevice(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikegw/manage/queryIotDeviceByName":
				if type == .requestBody {
                    body = BikebhtPostQueryIotDeviceByName()
                } else {
                    body = BikebhtRetQueryIotDeviceByName(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikegw/manage/queryIotDeviceList":
				if type == .requestBody {
                    body = BikebhtPostQueryIotDeviceList()
                } else {
                    body = BikebhtRetQueryIotDeviceList(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikegw/manage/iotCmd":
				if type == .requestBody {
                    body = BikebhtPostIotCmd()
                } else {
                    body = BikebhtRetIotCmd(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikegw/manage/queryHeartBag":
				if type == .requestBody {
                    body = BikebhtPostQueryHeartBag()
                } else {
                    body = BikebhtRetQueryHeartBag(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikegw/manage/generateDeviceId":
				if type == .requestBody {
                    body = BikebhtPostGenerateDeviceId()
                } else {
                    body = BikebhtRetGenerateDeviceId(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bikebht/business/bhtquerydevicesTest":
				if type == .requestBody {
                    body = BikebhtPostBHTQueryDevicesTest()
                } else {
                    body = BikebhtRetBHTQueryDevicesTest(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						default:
			body = BaseITWebAPIBody()
        }
        body.context = self
        return body
    }
}


		
open class BikebhtPostBhtRequest : BaseITWebAPIBody {
	
	//
									open var serviceId:String?
    							open var appId:String?
    							open var terminalType:String?
    							open var requestType:String?
    							open var DeviceId:String?
    							open var parkNum:String?
    							open var cityCode:String?
    							open var bizType:String?
    							open var version:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/business/bhtrequest"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/business/bhtrequest"
        	}

	//-------> list
			    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let serviceId_ = secureKeys?["AES"]?.encrypt(original: self.serviceId) ?? ""
																					let appId_ = secureKeys?["AES"]?.encrypt(original: self.appId) ?? ""
																					let terminalType_ = secureKeys?["AES"]?.encrypt(original: self.terminalType) ?? ""
																					let requestType_ = secureKeys?["AES"]?.encrypt(original: self.requestType) ?? ""
																					let DeviceId_ = secureKeys?["AES"]?.encrypt(original: self.DeviceId) ?? ""
																					let parkNum_ = secureKeys?["AES"]?.encrypt(original: self.parkNum) ?? ""
																					let cityCode_ = self.cityCode;
																					let bizType_ = self.bizType;
																					let version_ = self.version;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("accessToken=" + (accessToken_ ?? ""))
																					md5.append("&serviceId=" + (serviceId_ ?? ""))
																					md5.append("&appId=" + (appId_ ?? ""))
																					md5.append("&terminalType=" + (terminalType_ ?? ""))
																					md5.append("&requestType=" + (requestType_ ?? ""))
																					md5.append("&DeviceId=" + (DeviceId_ ?? ""))
																					md5.append("&parkNum=" + (parkNum_ ?? ""))
																																			
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikebhtPostBhtRequest",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:11,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:11,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:11,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:11,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:11,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:11,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:11,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:11,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:11,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:11,field:"terminalType",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:11,value:terminalType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:11,field:"terminalType",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:11,field:"requestType",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:11,value:requestType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:11,field:"requestType",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:11,field:"DeviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:11,value:DeviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:11,field:"DeviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:11,field:"parkNum",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:11,value:parkNum_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:11,field:"parkNum",body:self))
												result.append(vo.onFieldBegin(.flat,index:8,length:11,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:8,length:11,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:8,length:11,field:"cityCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:9,length:11,field:"bizType",body:self))
				result.append(vo.onFieldValue(.flat,index:9,length:11,value:bizType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:9,length:11,field:"bizType",body:self))
												result.append(vo.onFieldBegin(.flat,index:10,length:11,field:"version",body:self))
				result.append(vo.onFieldValue(.flat,index:10,length:11,value:version_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:10,length:11,field:"version",body:self))
									result.append(vo.onFieldBegin(.flat,index:11,length:11,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:11,length:11,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:11,length:11,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BikebhtPostBhtRequest",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikebhtRetBhtRequest : BaseITWebAPIBody {
	
	//
												open var bizStatus:String?
    							open var reqStatus:String?
    							open var serviceId:String?
    							open var orderId:String?
    							open var operId:String?
    							open var bikeId:String?
    							open var reqExtra:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/business/bhtrequest"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/business/bhtrequest"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											bizStatus = visitableSource.getValue("bizStatus")
																											reqStatus = visitableSource.getValue("reqStatus")
																											serviceId = visitableSource.getValue("serviceId")
																											orderId = visitableSource.getValue("orderId")
																											operId = visitableSource.getValue("operId")
																											bikeId = visitableSource.getValue("bikeId")
																											reqExtra = visitableSource.getValue("reqExtra")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikebhtPostBHTTrip : BaseITWebAPIBody {
	
	//
									open var serviceId:String?
    							open var appId:String?
    							open var operId:String?
    							open var dataType:String?
    							open var cityCode:String?
    							open var deviceId:String?
    							open var deviceType:String?
    							open var terminalType:String?
    							open var lockStatus:String?
    							open var coordinate:String?
    							open var coordType:String?
    							open var bizExtra:String?
    							open var batteryLevel:String?
    							open var deviceStakeId:String?
    							open var version:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/bhttrip"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/bhttrip"
        	}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let serviceId_ = secureKeys?["AES"]?.encrypt(original: self.serviceId) ?? ""
																					let appId_ = secureKeys?["AES"]?.encrypt(original: self.appId) ?? ""
																					let operId_ = secureKeys?["AES"]?.encrypt(original: self.operId) ?? ""
																					let dataType_ = self.dataType;
																					let cityCode_ = self.cityCode;
																					let deviceId_ = self.deviceId;
																					let deviceType_ = self.deviceType;
																					let terminalType_ = self.terminalType;
																					let lockStatus_ = self.lockStatus;
																					let coordinate_ = secureKeys?["AES"]?.encrypt(original: self.coordinate) ?? ""
																					let coordType_ = self.coordType;
																					let bizExtra_ = self.bizExtra;
																					let batteryLevel_ = self.batteryLevel;
																					let deviceStakeId_ = self.deviceStakeId;
																					let version_ = self.version;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("accessToken=" + (accessToken_ ?? ""))
																					md5.append("&serviceId=" + (serviceId_ ?? ""))
																					md5.append("&appId=" + (appId_ ?? ""))
																					md5.append("&operId=" + (operId_ ?? ""))
																																																															md5.append("&coordinate=" + (coordinate_ ?? ""))
																																																	
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikebhtPostBHTTrip",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:17,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:17,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:17,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:17,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:17,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:17,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:17,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:17,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:17,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:17,field:"operId",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:17,value:operId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:17,field:"operId",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:17,field:"dataType",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:17,value:dataType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:17,field:"dataType",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:17,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:17,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:17,field:"cityCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:17,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:17,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:17,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:8,length:17,field:"deviceType",body:self))
				result.append(vo.onFieldValue(.flat,index:8,length:17,value:deviceType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:8,length:17,field:"deviceType",body:self))
												result.append(vo.onFieldBegin(.flat,index:9,length:17,field:"terminalType",body:self))
				result.append(vo.onFieldValue(.flat,index:9,length:17,value:terminalType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:9,length:17,field:"terminalType",body:self))
												result.append(vo.onFieldBegin(.flat,index:10,length:17,field:"lockStatus",body:self))
				result.append(vo.onFieldValue(.flat,index:10,length:17,value:lockStatus_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:10,length:17,field:"lockStatus",body:self))
												result.append(vo.onFieldBegin(.flat,index:11,length:17,field:"coordinate",body:self))
				result.append(vo.onFieldValue(.flat,index:11,length:17,value:coordinate_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:11,length:17,field:"coordinate",body:self))
												result.append(vo.onFieldBegin(.flat,index:12,length:17,field:"coordType",body:self))
				result.append(vo.onFieldValue(.flat,index:12,length:17,value:coordType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:12,length:17,field:"coordType",body:self))
												result.append(vo.onFieldBegin(.flat,index:13,length:17,field:"bizExtra",body:self))
				result.append(vo.onFieldValue(.flat,index:13,length:17,value:bizExtra_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:13,length:17,field:"bizExtra",body:self))
												result.append(vo.onFieldBegin(.flat,index:14,length:17,field:"batteryLevel",body:self))
				result.append(vo.onFieldValue(.flat,index:14,length:17,value:batteryLevel_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:14,length:17,field:"batteryLevel",body:self))
												result.append(vo.onFieldBegin(.flat,index:15,length:17,field:"deviceStakeId",body:self))
				result.append(vo.onFieldValue(.flat,index:15,length:17,value:deviceStakeId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:15,length:17,field:"deviceStakeId",body:self))
												result.append(vo.onFieldBegin(.flat,index:16,length:17,field:"version",body:self))
				result.append(vo.onFieldValue(.flat,index:16,length:17,value:version_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:16,length:17,field:"version",body:self))
									result.append(vo.onFieldBegin(.flat,index:17,length:17,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:17,length:17,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:17,length:17,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BikebhtPostBHTTrip",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikebhtRetBHTTrip : BaseITWebAPIBody {
	
	//
												open var reqStatus:String?
    							open var serviceId:String?
    							open var operTime:String?
    							open var orderId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/bhttrip"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/bhttrip"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											reqStatus = visitableSource.getValue("reqStatus")
																											serviceId = visitableSource.getValue("serviceId")
																											operTime = visitableSource.getValue("operTime")
																											orderId = visitableSource.getValue("orderId")
															}

	//-------> list
			    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikebhtPostBHTQueryDevices : BaseITWebAPIBody {
	
	//
						open var appId:String?
    							open var serviceId:String?
    							open var keyword:String?
    							open var coordinate:String?
    							open var coordType:String?
    							open var range:String?
    							open var type:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/business/bhtquerydevices"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/business/bhtquerydevices"
        	}

	//-------> list
			    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let appId_ = secureKeys?["AES"]?.encrypt(original: self.appId) ?? ""
																					let serviceId_ = secureKeys?["AES"]?.encrypt(original: self.serviceId) ?? ""
																					let keyword_ = secureKeys?["AES"]?.encrypt(original: self.keyword) ?? ""
																					let coordinate_ = secureKeys?["AES"]?.encrypt(original: self.coordinate) ?? ""
																					let coordType_ = secureKeys?["AES"]?.encrypt(original: self.coordType) ?? ""
																					let range_ = secureKeys?["AES"]?.encrypt(original: self.range) ?? ""
																					let type_ = self.type;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("appId=" + (appId_ ?? ""))
																					md5.append("&serviceId=" + (serviceId_ ?? ""))
																					md5.append("&keyword=" + (keyword_ ?? ""))
																					md5.append("&coordinate=" + (coordinate_ ?? ""))
																					md5.append("&coordType=" + (coordType_ ?? ""))
																					md5.append("&range=" + (range_ ?? ""))
																					md5.append("&type=" + (type_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikebhtPostBHTQueryDevices",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:8,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:8,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:8,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:8,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:8,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:8,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:8,field:"keyword",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:8,value:keyword_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:8,field:"keyword",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:8,field:"coordinate",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:8,value:coordinate_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:8,field:"coordinate",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:8,field:"coordType",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:8,value:coordType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:8,field:"coordType",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:8,field:"range",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:8,value:range_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:8,field:"range",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:8,field:"type",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:8,value:type_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:8,field:"type",body:self))
									result.append(vo.onFieldBegin(.flat,index:8,length:8,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:8,length:8,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:8,length:8,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BikebhtPostBHTQueryDevices",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikebhtRetBHTQueryDevices : BaseITWebAPIBody {
	
	//
												open var datacount:String?
    				    		//----->list
			fileprivate var data = [BikebhtRetBHTQueryDevicesDetail]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/business/bhtquerydevices"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/business/bhtquerydevices"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											datacount = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("datacount"))
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( RetBHTQueryDevicesDetail (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addData(subBody:RetBHTQueryDevicesDetail) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [RetBHTQueryDevicesDetail]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class BikebhtRetBHTQueryDevicesDetail : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    							open var cityCode:String?
    							open var deviceName:String?
    							open var coordinate:String?
    							open var coordType:String?
    							open var address:String?
    							open var status:String?
    							open var updatetime:String?
    							open var totalcount:String?
    							open var rentcount:String?
    							open var restorecount:String?
    							open var type:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/business/bhtquerydevices"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/business/bhtquerydevices"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		deviceId = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("deviceId"))
																											cityCode = visitableSource.getValue("cityCode")
																											deviceName = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("deviceName"))
																											coordinate = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("coordinate"))
																											coordType = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("coordType"))
																											address = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("address"))
																											status = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("status"))
																											updatetime = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("updatetime"))
																											totalcount = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("totalcount"))
																											rentcount = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("rentcount"))
																											restorecount = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("restorecount"))
																											type = visitableSource.getValue("type")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class BikebhtPostFirmwareUpdate : BaseITWebAPIBody {
	
	//
									open var cityCode:String?
    							open var deviceType:String?
    							open var deviceId:String?
    							open var produceCom:String?
    							open var softVersion:String?
    							open var deviceInfo:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/firmwareupdate"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/firmwareupdate"
        	}

	//-------> list
			    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let cityCode_ = self.cityCode;
																					let deviceType_ = self.deviceType;
																					let deviceId_ = self.deviceId;
																					let produceCom_ = self.produceCom;
																					let softVersion_ = self.softVersion;
																					let deviceInfo_ = self.deviceInfo;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("accessToken=" + (accessToken_ ?? ""))
																																																								
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikebhtPostFirmwareUpdate",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:8,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:8,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:8,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:8,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:8,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:8,field:"cityCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:8,field:"deviceType",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:8,value:deviceType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:8,field:"deviceType",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:8,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:8,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:8,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:8,field:"produceCom",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:8,value:produceCom_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:8,field:"produceCom",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:8,field:"softVersion",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:8,value:softVersion_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:8,field:"softVersion",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:8,field:"deviceInfo",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:8,value:deviceInfo_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:8,field:"deviceInfo",body:self))
									result.append(vo.onFieldBegin(.flat,index:8,length:8,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:8,length:8,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:8,length:8,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BikebhtPostFirmwareUpdate",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikebhtRetFirmwareUpdate : BaseITWebAPIBody {
	
	//
												open var reqStatus:String?
    							open var updateTime:String?
    							open var updateInfo:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/firmwareupdate"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/firmwareupdate"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											reqStatus = visitableSource.getValue("reqStatus")
																											updateTime = visitableSource.getValue("updateTime")
																											updateInfo = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("updateInfo"))
															}

	//-------> list
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikebhtPostDevLifecycle : BaseITWebAPIBody {
	
	//
									open var cityCode:String?
    							open var deviceId:String?
    							open var mgrType:String?
    							open var devType:String?
    							open var devName:String?
    							open var lockStatus:String?
    							open var productSn:String?
    							open var devMac:String?
    							open var qrCode:String?
    							open var hardVer:String?
    							open var softVer:String?
    							open var produceCom:String?
    							open var coordinate:String?
    							open var coordType:String?
    							open var batteryCap:String?
    							open var batteryLevel:String?
    							open var createor:String?
    							open var extInfo:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/devlifecycle"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/devlifecycle"
        	}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let cityCode_ = self.cityCode;
																					let deviceId_ = self.deviceId;
																					let mgrType_ = self.mgrType;
																					let devType_ = self.devType;
																					let devName_ = self.devName;
																					let lockStatus_ = self.lockStatus;
																					let productSn_ = self.productSn;
																					let devMac_ = self.devMac;
																					let qrCode_ = self.qrCode;
																					let hardVer_ = self.hardVer;
																					let softVer_ = self.softVer;
																					let produceCom_ = self.produceCom;
																					let coordinate_ = self.coordinate;
																					let coordType_ = self.coordType;
																					let batteryCap_ = self.batteryCap;
																					let batteryLevel_ = self.batteryLevel;
																					let createor_ = self.createor;
																					let extInfo_ = self.extInfo;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikebhtPostDevLifecycle",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:20,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:20,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:20,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:20,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:20,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:20,field:"cityCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:20,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:20,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:20,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:20,field:"mgrType",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:20,value:mgrType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:20,field:"mgrType",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:20,field:"devType",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:20,value:devType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:20,field:"devType",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:20,field:"devName",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:20,value:devName_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:20,field:"devName",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:20,field:"lockStatus",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:20,value:lockStatus_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:20,field:"lockStatus",body:self))
												result.append(vo.onFieldBegin(.flat,index:8,length:20,field:"productSn",body:self))
				result.append(vo.onFieldValue(.flat,index:8,length:20,value:productSn_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:8,length:20,field:"productSn",body:self))
												result.append(vo.onFieldBegin(.flat,index:9,length:20,field:"devMac",body:self))
				result.append(vo.onFieldValue(.flat,index:9,length:20,value:devMac_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:9,length:20,field:"devMac",body:self))
												result.append(vo.onFieldBegin(.flat,index:10,length:20,field:"qrCode",body:self))
				result.append(vo.onFieldValue(.flat,index:10,length:20,value:qrCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:10,length:20,field:"qrCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:11,length:20,field:"hardVer",body:self))
				result.append(vo.onFieldValue(.flat,index:11,length:20,value:hardVer_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:11,length:20,field:"hardVer",body:self))
												result.append(vo.onFieldBegin(.flat,index:12,length:20,field:"softVer",body:self))
				result.append(vo.onFieldValue(.flat,index:12,length:20,value:softVer_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:12,length:20,field:"softVer",body:self))
												result.append(vo.onFieldBegin(.flat,index:13,length:20,field:"produceCom",body:self))
				result.append(vo.onFieldValue(.flat,index:13,length:20,value:produceCom_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:13,length:20,field:"produceCom",body:self))
												result.append(vo.onFieldBegin(.flat,index:14,length:20,field:"coordinate",body:self))
				result.append(vo.onFieldValue(.flat,index:14,length:20,value:coordinate_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:14,length:20,field:"coordinate",body:self))
												result.append(vo.onFieldBegin(.flat,index:15,length:20,field:"coordType",body:self))
				result.append(vo.onFieldValue(.flat,index:15,length:20,value:coordType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:15,length:20,field:"coordType",body:self))
												result.append(vo.onFieldBegin(.flat,index:16,length:20,field:"batteryCap",body:self))
				result.append(vo.onFieldValue(.flat,index:16,length:20,value:batteryCap_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:16,length:20,field:"batteryCap",body:self))
												result.append(vo.onFieldBegin(.flat,index:17,length:20,field:"batteryLevel",body:self))
				result.append(vo.onFieldValue(.flat,index:17,length:20,value:batteryLevel_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:17,length:20,field:"batteryLevel",body:self))
												result.append(vo.onFieldBegin(.flat,index:18,length:20,field:"createor",body:self))
				result.append(vo.onFieldValue(.flat,index:18,length:20,value:createor_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:18,length:20,field:"createor",body:self))
												result.append(vo.onFieldBegin(.flat,index:19,length:20,field:"extInfo",body:self))
				result.append(vo.onFieldValue(.flat,index:19,length:20,value:extInfo_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:19,length:20,field:"extInfo",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikebhtPostDevLifecycle",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikebhtRetDevLifecycle : BaseITWebAPIBody {
	
	//
												open var reqStatus:String?
    							open var mgrTime:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/devlifecycle"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/devlifecycle"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											reqStatus = visitableSource.getValue("reqStatus")
																											mgrTime = visitableSource.getValue("mgrTime")
															}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikebhtPostBhtDevBasicInfo : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    							open var cityCode:String?
    							open var deviceType:String?
    							open var version:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/getbhtlock"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/getbhtlock"
        	}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																					let cityCode_ = self.cityCode;
																					let deviceType_ = self.deviceType;
																					let version_ = self.version;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikebhtPostBhtDevBasicInfo",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:5,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:5,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:5,field:"cityCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:5,field:"deviceType",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:5,value:deviceType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:5,field:"deviceType",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:5,field:"version",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:5,value:version_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:5,field:"version",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikebhtPostBhtDevBasicInfo",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikebhtRetBhtDevBasicInfo : BaseITWebAPIBody {
	
	//
												open var reqStatus:String?
    							open var deviceId:String?
    							open var devName:String?
    							open var devType:String?
    							open var qrCode:String?
    							open var cityCode:String?
    							open var productSn:String?
    							open var devSpec:String?
    							open var devStatus:String?
    							open var lifecycle:String?
    							open var produceCom:String?
    							open var hardVer:String?
    							open var softVer:String?
    							open var devMac:String?
    							open var batteryCap:String?
    							open var createor:String?
    							open var onlineStatus:String?
    							open var createTime:String?
    							open var updateTime:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/getbhtlock"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/getbhtlock"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											reqStatus = visitableSource.getValue("reqStatus")
																											deviceId = visitableSource.getValue("deviceId")
																											devName = visitableSource.getValue("devName")
																											devType = visitableSource.getValue("devType")
																											qrCode = visitableSource.getValue("qrCode")
																											cityCode = visitableSource.getValue("cityCode")
																											productSn = visitableSource.getValue("productSn")
																											devSpec = visitableSource.getValue("devSpec")
																											devStatus = visitableSource.getValue("devStatus")
																											lifecycle = visitableSource.getValue("lifecycle")
																											produceCom = visitableSource.getValue("produceCom")
																											hardVer = visitableSource.getValue("hardVer")
																											softVer = visitableSource.getValue("softVer")
																											devMac = visitableSource.getValue("devMac")
																											batteryCap = visitableSource.getValue("batteryCap")
																											createor = visitableSource.getValue("createor")
																											onlineStatus = visitableSource.getValue("onlineStatus")
																											createTime = visitableSource.getValue("createTime")
																											updateTime = visitableSource.getValue("updateTime")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikebhtPostDelDevBasicInfo : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    							open var cityCode:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/deletebhtdev"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/deletebhtdev"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																					let cityCode_ = self.cityCode;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikebhtPostDelDevBasicInfo",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"cityCode",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikebhtPostDelDevBasicInfo",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikebhtRetDelDevBasicInfo : BaseITWebAPIBody {
	
	//
												open var reqStatus:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/deletebhtdev"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/deletebhtdev"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											reqStatus = visitableSource.getValue("reqStatus")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikebhtPostDevLocInfo : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    							open var cityCode:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/getbhtloc"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/getbhtloc"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																					let cityCode_ = self.cityCode;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikebhtPostDevLocInfo",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"cityCode",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikebhtPostDevLocInfo",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikebhtRetDevLocInfo : BaseITWebAPIBody {
	
	//
												open var reqStatus:String?
    							open var deviceId:String?
    							open var devType:String?
    							open var devName:String?
    							open var cityCode:String?
    							open var cordinate:String?
    							open var coordType:String?
    							open var geoHash:String?
    							open var lUCordinate:String?
    							open var lDCordinate:String?
    							open var rUCordinate:String?
    							open var rDCordinate:String?
    							open var updateTime:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/getbhtloc"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/getbhtloc"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											reqStatus = visitableSource.getValue("reqStatus")
																											deviceId = visitableSource.getValue("deviceId")
																											devType = visitableSource.getValue("devType")
																											devName = visitableSource.getValue("devName")
																											cityCode = visitableSource.getValue("cityCode")
																											cordinate = visitableSource.getValue("cordinate")
																											coordType = visitableSource.getValue("coordType")
																											geoHash = visitableSource.getValue("geoHash")
																											lUCordinate = visitableSource.getValue("lUCordinate")
																											lDCordinate = visitableSource.getValue("lDCordinate")
																											rUCordinate = visitableSource.getValue("rUCordinate")
																											rDCordinate = visitableSource.getValue("rDCordinate")
																											updateTime = visitableSource.getValue("updateTime")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikebhtPostBhtLockInfoList : BaseITWebAPIBody {
	
	//
						open var cityCode:String?
    							open var deviceType:String?
    							open var deviceId:String?
    							open var qrCode:String?
    							open var beginindex:String?
    							open var retcount:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/getbhtlocklist"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/getbhtlocklist"
        	}

	//-------> list
			    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let cityCode_ = self.cityCode;
																					let deviceType_ = self.deviceType;
																					let deviceId_ = self.deviceId;
																					let qrCode_ = self.qrCode;
																					let beginindex_ = self.beginindex;
																					let retcount_ = self.retcount;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikebhtPostBhtLockInfoList",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:7,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:7,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:7,field:"cityCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:7,field:"deviceType",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:7,value:deviceType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:7,field:"deviceType",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:7,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:7,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:7,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:7,field:"qrCode",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:7,value:qrCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:7,field:"qrCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:7,field:"beginindex",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:7,value:beginindex_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:7,field:"beginindex",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:7,field:"retcount",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:7,value:retcount_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:7,field:"retcount",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikebhtPostBhtLockInfoList",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikebhtRetBhtLockInfoList : BaseITWebAPIBody {
	
	//
												open var reqStatus:String?
    							open var datacount:String?
    				    		//----->list
			fileprivate var data = [BikebhtRetDevicesInfo]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/getbhtlocklist"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/getbhtlocklist"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											reqStatus = visitableSource.getValue("reqStatus")
																											datacount = visitableSource.getValue("datacount")
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( RetDevicesInfo (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    		    			    open func addData(subBody:RetDevicesInfo) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [RetDevicesInfo]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																													
open class BikebhtRetDevicesInfo : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    							open var devType:String?
    							open var devName:String?
    							open var cityCode:String?
    							open var qrCode:String?
    							open var productSn:String?
    							open var lifecycle:String?
    							open var devMac:String?
    							open var batteryCap:String?
    							open var lockType:String?
    							open var lockStatus:String?
    							open var batteryLevel:String?
    							open var rentCount:String?
    							open var stationId:String?
    							open var userId:String?
    							open var userStatus:String?
    							open var onlineStatus:String?
    							open var updateTime:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/getbhtlocklist"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/getbhtlocklist"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		deviceId = visitableSource.getValue("deviceId")
																											devType = visitableSource.getValue("devType")
																											devName = visitableSource.getValue("devName")
																											cityCode = visitableSource.getValue("cityCode")
																											qrCode = visitableSource.getValue("qrCode")
																											productSn = visitableSource.getValue("productSn")
																											lifecycle = visitableSource.getValue("lifecycle")
																											devMac = visitableSource.getValue("devMac")
																											batteryCap = visitableSource.getValue("batteryCap")
																											lockType = visitableSource.getValue("lockType")
																											lockStatus = visitableSource.getValue("lockStatus")
																											batteryLevel = visitableSource.getValue("batteryLevel")
																											rentCount = visitableSource.getValue("rentCount")
																											stationId = visitableSource.getValue("stationId")
																											userId = visitableSource.getValue("userId")
																											userStatus = visitableSource.getValue("userStatus")
																											onlineStatus = visitableSource.getValue("onlineStatus")
																											updateTime = visitableSource.getValue("updateTime")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class BikebhtPostDevAuth : BaseITWebAPIBody {
	
	//
						open var mac:String?
    							open var phone:String?
    							open var name:String?
    							open var cityCode:String?
    							open var cityName:String?
    							open var remark:String?
    							open var col1:String?
    							open var col2:String?
    							open var col3:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/devAuth"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/devAuth"
        	}

	//-------> list
			    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let mac_ = self.mac;
																					let phone_ = self.phone;
																					let name_ = self.name;
																					let cityCode_ = self.cityCode;
																					let cityName_ = self.cityName;
																					let remark_ = self.remark;
																					let col1_ = self.col1;
																					let col2_ = self.col2;
																					let col3_ = self.col3;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikebhtPostDevAuth",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:10,field:"mac",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:10,value:mac_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:10,field:"mac",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:10,field:"phone",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:10,value:phone_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:10,field:"phone",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:10,field:"name",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:10,value:name_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:10,field:"name",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:10,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:10,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:10,field:"cityCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:10,field:"cityName",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:10,value:cityName_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:10,field:"cityName",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:10,field:"remark",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:10,value:remark_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:10,field:"remark",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:10,field:"col1",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:10,value:col1_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:10,field:"col1",body:self))
												result.append(vo.onFieldBegin(.flat,index:8,length:10,field:"col2",body:self))
				result.append(vo.onFieldValue(.flat,index:8,length:10,value:col2_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:8,length:10,field:"col2",body:self))
												result.append(vo.onFieldBegin(.flat,index:9,length:10,field:"col3",body:self))
				result.append(vo.onFieldValue(.flat,index:9,length:10,value:col3_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:9,length:10,field:"col3",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikebhtPostDevAuth",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikebhtRetDevAuth : BaseITWebAPIBody {
	
	//
												open var reqStatus:String?
    							open var mgrTime:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/devAuth"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/devAuth"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											reqStatus = visitableSource.getValue("reqStatus")
																											mgrTime = visitableSource.getValue("mgrTime")
															}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikebhtPostQueryDevAuthList : BaseITWebAPIBody {
	
	//
						open var mac:String?
    							open var beginindex:String?
    							open var retcount:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/queryDevAuthList"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/queryDevAuthList"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let mac_ = self.mac;
																					let beginindex_ = self.beginindex;
																					let retcount_ = self.retcount;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikebhtPostQueryDevAuthList",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"mac",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:mac_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"mac",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"beginindex",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:beginindex_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"beginindex",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"retcount",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:retcount_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"retcount",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikebhtPostQueryDevAuthList",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikebhtRetQueryDevAuthList : BaseITWebAPIBody {
	
	//
												open var reqStatus:String?
    							open var datacount:String?
    				    		//----->list
			fileprivate var data = [BikebhtRetDevAuthInfo]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/queryDevAuthList"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/queryDevAuthList"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											reqStatus = visitableSource.getValue("reqStatus")
																											datacount = visitableSource.getValue("datacount")
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( RetDevAuthInfo (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    		    			    open func addData(subBody:RetDevAuthInfo) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [RetDevAuthInfo]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																													
open class BikebhtRetDevAuthInfo : BaseITWebAPIBody {
	
	//
						open var mac:String?
    							open var phone:String?
    							open var name:String?
    							open var auth:String?
    							open var cityCode:String?
    							open var cityName:String?
    							open var remark:String?
    							open var createTime:String?
    							open var updateTime:String?
    							open var col1:String?
    							open var col2:String?
    							open var col3:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/queryDevAuthList"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/queryDevAuthList"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		mac = visitableSource.getValue("mac")
																											phone = visitableSource.getValue("phone")
																											name = visitableSource.getValue("name")
																											auth = visitableSource.getValue("auth")
																											cityCode = visitableSource.getValue("cityCode")
																											cityName = visitableSource.getValue("cityName")
																											remark = visitableSource.getValue("remark")
																											createTime = visitableSource.getValue("createTime")
																											updateTime = visitableSource.getValue("updateTime")
																											col1 = visitableSource.getValue("col1")
																											col2 = visitableSource.getValue("col2")
																											col3 = visitableSource.getValue("col3")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class BikebhtPostUpdateDevAuth : BaseITWebAPIBody {
	
	//
						open var mac:String?
    							open var phone:String?
    							open var name:String?
    							open var auth:String?
    							open var cityCode:String?
    							open var cityName:String?
    							open var remark:String?
    							open var col1:String?
    							open var col2:String?
    							open var col3:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/updateDevAuth"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/updateDevAuth"
        	}

	//-------> list
			    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let mac_ = self.mac;
																					let phone_ = self.phone;
																					let name_ = self.name;
																					let auth_ = self.auth;
																					let cityCode_ = self.cityCode;
																					let cityName_ = self.cityName;
																					let remark_ = self.remark;
																					let col1_ = self.col1;
																					let col2_ = self.col2;
																					let col3_ = self.col3;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikebhtPostUpdateDevAuth",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:11,field:"mac",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:11,value:mac_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:11,field:"mac",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:11,field:"phone",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:11,value:phone_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:11,field:"phone",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:11,field:"name",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:11,value:name_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:11,field:"name",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:11,field:"auth",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:11,value:auth_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:11,field:"auth",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:11,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:11,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:11,field:"cityCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:11,field:"cityName",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:11,value:cityName_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:11,field:"cityName",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:11,field:"remark",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:11,value:remark_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:11,field:"remark",body:self))
												result.append(vo.onFieldBegin(.flat,index:8,length:11,field:"col1",body:self))
				result.append(vo.onFieldValue(.flat,index:8,length:11,value:col1_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:8,length:11,field:"col1",body:self))
												result.append(vo.onFieldBegin(.flat,index:9,length:11,field:"col2",body:self))
				result.append(vo.onFieldValue(.flat,index:9,length:11,value:col2_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:9,length:11,field:"col2",body:self))
												result.append(vo.onFieldBegin(.flat,index:10,length:11,field:"col3",body:self))
				result.append(vo.onFieldValue(.flat,index:10,length:11,value:col3_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:10,length:11,field:"col3",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikebhtPostUpdateDevAuth",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikebhtRetUpdateDevAuth : BaseITWebAPIBody {
	
	//
												open var reqStatus:String?
    							open var mgrTime:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/updateDevAuth"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/updateDevAuth"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											reqStatus = visitableSource.getValue("reqStatus")
																											mgrTime = visitableSource.getValue("mgrTime")
															}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikebhtPostBhtLockInfoToOpera : BaseITWebAPIBody {
	
	//
						open var qrCode:String?
    							open var deviceId:String?
    							open var cityCode:String?
    							open var beginindex:String?
    							open var retcount:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/getbhtlockinfotoopera"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/getbhtlockinfotoopera"
        	}

	//-------> list
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let qrCode_ = self.qrCode;
																					let deviceId_ = self.deviceId;
																					let cityCode_ = self.cityCode;
																					let beginindex_ = self.beginindex;
																					let retcount_ = self.retcount;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikebhtPostBhtLockInfoToOpera",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:6,field:"qrCode",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:6,value:qrCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:6,field:"qrCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:6,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:6,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:6,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:6,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:6,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:6,field:"cityCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:6,field:"beginindex",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:6,value:beginindex_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:6,field:"beginindex",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:6,field:"retcount",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:6,value:retcount_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:6,field:"retcount",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikebhtPostBhtLockInfoToOpera",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikebhtRetBhtLockInfoToOpera : BaseITWebAPIBody {
	
	//
												open var reqStatus:String?
    							open var datacount:String?
    				    		//----->list
			fileprivate var data = [BikebhtRetBhtInfo]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/getbhtlockinfotoopera"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/getbhtlockinfotoopera"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											reqStatus = visitableSource.getValue("reqStatus")
																											datacount = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("datacount"))
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( RetBhtInfo (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    		    			    open func addData(subBody:RetBhtInfo) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [RetBhtInfo]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																													
open class BikebhtRetBhtInfo : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    							open var devName:String?
    							open var devType:String?
    							open var qrCode:String?
    							open var cityCode:String?
    							open var productSn:String?
    							open var devSpec:String?
    							open var devStatus:String?
    							open var lifecycle:String?
    							open var produceCom:String?
    							open var hardVer:String?
    							open var softVer:String?
    							open var devMac:String?
    							open var batteryCap:String?
    							open var createor:String?
    							open var createTime:String?
    							open var updateTime:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/getbhtlockinfotoopera"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/getbhtlockinfotoopera"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		deviceId = visitableSource.getValue("deviceId")
																											devName = visitableSource.getValue("devName")
																											devType = visitableSource.getValue("devType")
																											qrCode = visitableSource.getValue("qrCode")
																											cityCode = visitableSource.getValue("cityCode")
																											productSn = visitableSource.getValue("productSn")
																											devSpec = visitableSource.getValue("devSpec")
																											devStatus = visitableSource.getValue("devStatus")
																											lifecycle = visitableSource.getValue("lifecycle")
																											produceCom = visitableSource.getValue("produceCom")
																											hardVer = visitableSource.getValue("hardVer")
																											softVer = visitableSource.getValue("softVer")
																											devMac = visitableSource.getValue("devMac")
																											batteryCap = visitableSource.getValue("batteryCap")
																											createor = visitableSource.getValue("createor")
																											createTime = visitableSource.getValue("createTime")
																											updateTime = visitableSource.getValue("updateTime")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class BikebhtPostBhtLockInfo : BaseITWebAPIBody {
	
	//
									open var serviceId:String?
    							open var qrCode:String?
    							open var deviceId:String?
    							open var cityCode:String?
    							open var version:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/getbhtlockinfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/getbhtlockinfo"
        	}

	//-------> list
			    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let serviceId_ = self.serviceId;
																					let qrCode_ = self.qrCode;
																					let deviceId_ = self.deviceId;
																					let cityCode_ = self.cityCode;
																					let version_ = self.version;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikebhtPostBhtLockInfo",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:7,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:7,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:7,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:7,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:7,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:7,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:7,field:"qrCode",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:7,value:qrCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:7,field:"qrCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:7,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:7,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:7,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:7,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:7,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:7,field:"cityCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:7,field:"version",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:7,value:version_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:7,field:"version",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikebhtPostBhtLockInfo",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikebhtRetBhtLockInfo : BaseITWebAPIBody {
	
	//
												open var reqStatus:String?
    							open var deviceId:String?
    							open var devName:String?
    							open var devType:String?
    							open var qrCode:String?
    							open var cityCode:String?
    							open var productSn:String?
    							open var devSpec:String?
    							open var devStatus:String?
    							open var lifecycle:String?
    							open var produceCom:String?
    							open var hardVer:String?
    							open var softVer:String?
    							open var devMac:String?
    							open var batteryCap:String?
    							open var createor:String?
    							open var createTime:String?
    							open var updateTime:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/getbhtlockinfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/getbhtlockinfo"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											reqStatus = visitableSource.getValue("reqStatus")
																											deviceId = visitableSource.getValue("deviceId")
																											devName = visitableSource.getValue("devName")
																											devType = visitableSource.getValue("devType")
																											qrCode = visitableSource.getValue("qrCode")
																											cityCode = visitableSource.getValue("cityCode")
																											productSn = visitableSource.getValue("productSn")
																											devSpec = visitableSource.getValue("devSpec")
																											devStatus = visitableSource.getValue("devStatus")
																											lifecycle = visitableSource.getValue("lifecycle")
																											produceCom = visitableSource.getValue("produceCom")
																											hardVer = visitableSource.getValue("hardVer")
																											softVer = visitableSource.getValue("softVer")
																											devMac = visitableSource.getValue("devMac")
																											batteryCap = visitableSource.getValue("batteryCap")
																											createor = visitableSource.getValue("createor")
																											createTime = visitableSource.getValue("createTime")
																											updateTime = visitableSource.getValue("updateTime")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikebhtPostBhtLockInfoApp : BaseITWebAPIBody {
	
	//
									open var qrCode:String?
    							open var deviceId:String?
    							open var cityCode:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/getbhtlockinfoApp"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/getbhtlockinfoApp"
        	}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let qrCode_ = self.qrCode;
																					let deviceId_ = self.deviceId;
																					let cityCode_ = self.cityCode;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikebhtPostBhtLockInfoApp",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:5,field:"qrCode",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:5,value:qrCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:5,field:"qrCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:5,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:5,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:5,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:5,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:5,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:5,field:"cityCode",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikebhtPostBhtLockInfoApp",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikebhtRetBhtLockInfoApp : BaseITWebAPIBody {
	
	//
												open var reqStatus:String?
    							open var deviceId:String?
    							open var devName:String?
    							open var devType:String?
    							open var qrCode:String?
    							open var cityCode:String?
    							open var productSn:String?
    							open var devSpec:String?
    							open var devStatus:String?
    							open var lifecycle:String?
    							open var produceCom:String?
    							open var hardVer:String?
    							open var softVer:String?
    							open var devMac:String?
    							open var batteryCap:String?
    							open var createor:String?
    							open var createTime:String?
    							open var updateTime:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/getbhtlockinfoApp"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/getbhtlockinfoApp"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											reqStatus = visitableSource.getValue("reqStatus")
																											deviceId = visitableSource.getValue("deviceId")
																											devName = visitableSource.getValue("devName")
																											devType = visitableSource.getValue("devType")
																											qrCode = visitableSource.getValue("qrCode")
																											cityCode = visitableSource.getValue("cityCode")
																											productSn = visitableSource.getValue("productSn")
																											devSpec = visitableSource.getValue("devSpec")
																											devStatus = visitableSource.getValue("devStatus")
																											lifecycle = visitableSource.getValue("lifecycle")
																											produceCom = visitableSource.getValue("produceCom")
																											hardVer = visitableSource.getValue("hardVer")
																											softVer = visitableSource.getValue("softVer")
																											devMac = visitableSource.getValue("devMac")
																											batteryCap = visitableSource.getValue("batteryCap")
																											createor = visitableSource.getValue("createor")
																											createTime = visitableSource.getValue("createTime")
																											updateTime = visitableSource.getValue("updateTime")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikebhtPostCitycodeInfo : BaseITWebAPIBody {
	
	//
						open var area:String?
    							open var city:String?
    							open var beginindex:String?
    							open var retcount:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/citycodeinfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/citycodeinfo"
        	}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let area_ = self.area;
																					let city_ = self.city;
																					let beginindex_ = self.beginindex;
																					let retcount_ = self.retcount;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikebhtPostCitycodeInfo",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"area",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:area_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"area",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:5,field:"city",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:5,value:city_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:5,field:"city",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:5,field:"beginindex",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:5,value:beginindex_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:5,field:"beginindex",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:5,field:"retcount",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:5,value:retcount_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:5,field:"retcount",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikebhtPostCitycodeInfo",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikebhtRetCitycodeInfo : BaseITWebAPIBody {
	
	//
												open var datacount:String?
    				    		//----->list
			fileprivate var data = [BikebhtRetCityCodeInfo]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/citycodeinfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/citycodeinfo"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											datacount = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("datacount"))
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( RetCityCodeInfo (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addData(subBody:RetCityCodeInfo) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [RetCityCodeInfo]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class BikebhtRetCityCodeInfo : BaseITWebAPIBody {
	
	//
						open var province:String?
    							open var city:String?
    							open var area:String?
    							open var zoneNum:String?
    							open var orderNum:String?
    							open var cityCode:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/citycodeinfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/citycodeinfo"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		province = visitableSource.getValue("province")
																											city = visitableSource.getValue("city")
																											area = visitableSource.getValue("area")
																											zoneNum = visitableSource.getValue("zoneNum")
																											orderNum = visitableSource.getValue("orderNum")
																											cityCode = visitableSource.getValue("cityCode")
															}

	//-------> list
			    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class BikebhtPostStationInfoCollect : BaseITWebAPIBody {
	
	//
						open var stationId:String?
    							open var macList:String?
    							open var cityCode:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/stationInfoCollect"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/stationInfoCollect"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let stationId_ = self.stationId;
																					let macList_ = self.macList;
																					let cityCode_ = self.cityCode;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikebhtPostStationInfoCollect",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"stationId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:stationId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"stationId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"macList",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:macList_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"macList",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"cityCode",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikebhtPostStationInfoCollect",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikebhtRetStationInfoCollect : BaseITWebAPIBody {
	
	//
												open var result:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/stationInfoCollect"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/device/stationInfoCollect"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											result = visitableSource.getValue("result")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikebhtPostManageRequest : BaseITWebAPIBody {
	
	//
									open var serviceId:String?
    							open var appId:String?
    							open var terminalType:String?
    							open var macAddr:String?
    							open var deviceId:String?
    							open var parkNum:String?
    							open var cityCode:String?
    							open var bizType:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/requestMgr"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/requestMgr"
        	}

	//-------> list
			    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let serviceId_ = self.serviceId;
																					let appId_ = self.appId;
																					let terminalType_ = self.terminalType;
																					let macAddr_ = self.macAddr;
																					let deviceId_ = self.deviceId;
																					let parkNum_ = self.parkNum;
																					let cityCode_ = self.cityCode;
																					let bizType_ = self.bizType;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikebhtPostManageRequest",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:10,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:10,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:10,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:10,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:10,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:10,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:10,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:10,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:10,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:10,field:"terminalType",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:10,value:terminalType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:10,field:"terminalType",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:10,field:"macAddr",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:10,value:macAddr_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:10,field:"macAddr",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:10,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:10,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:10,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:10,field:"parkNum",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:10,value:parkNum_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:10,field:"parkNum",body:self))
												result.append(vo.onFieldBegin(.flat,index:8,length:10,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:8,length:10,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:8,length:10,field:"cityCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:9,length:10,field:"bizType",body:self))
				result.append(vo.onFieldValue(.flat,index:9,length:10,value:bizType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:9,length:10,field:"bizType",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikebhtPostManageRequest",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikebhtRetManageRequest : BaseITWebAPIBody {
	
	//
												open var bizstatus:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/requestMgr"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/requestMgr"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											bizstatus = visitableSource.getValue("bizstatus")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikebhtPostManageGetVhcls : BaseITWebAPIBody {
	
	//
									open var serviceId:String?
    							open var appId:String?
    							open var cityCode:String?
    							open var terminalType:String?
    							open var macAddr:String?
    							open var bizType:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/getVhclsMgr"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/getVhclsMgr"
        	}

	//-------> list
			    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let serviceId_ = self.serviceId;
																					let appId_ = self.appId;
																					let cityCode_ = self.cityCode;
																					let terminalType_ = self.terminalType;
																					let macAddr_ = self.macAddr;
																					let bizType_ = self.bizType;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikebhtPostManageGetVhcls",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:8,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:8,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:8,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:8,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:8,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:8,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:8,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:8,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:8,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:8,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:8,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:8,field:"cityCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:8,field:"terminalType",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:8,value:terminalType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:8,field:"terminalType",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:8,field:"macAddr",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:8,value:macAddr_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:8,field:"macAddr",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:8,field:"bizType",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:8,value:bizType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:8,field:"bizType",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikebhtPostManageGetVhcls",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikebhtRetManageGetVhcls : BaseITWebAPIBody {
	
	//
												open var bizstatus:String?
    							open var vhclCount:String?
    				    		//----->list
			fileprivate var data = [BikebhtRetManageGetVhclsDetail]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/getVhclsMgr"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/getVhclsMgr"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											bizstatus = visitableSource.getValue("bizstatus")
																											vhclCount = visitableSource.getValue("vhclCount")
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( RetManageGetVhclsDetail (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    		    			    open func addData(subBody:RetManageGetVhclsDetail) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [RetManageGetVhclsDetail]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																													
open class BikebhtRetManageGetVhclsDetail : BaseITWebAPIBody {
	
	//
						open var vhclNum:String?
    							open var bizType:String?
    							open var lockType:String?
    							open var vhclStatus:String?
    							open var lockStatus:String?
    							open var pileLockStatus:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/getVhclsMgr"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/getVhclsMgr"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		vhclNum = visitableSource.getValue("vhclNum")
																											bizType = visitableSource.getValue("bizType")
																											lockType = visitableSource.getValue("lockType")
																											vhclStatus = visitableSource.getValue("vhclStatus")
																											lockStatus = visitableSource.getValue("lockStatus")
																											pileLockStatus = visitableSource.getValue("pileLockStatus")
															}

	//-------> list
			    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class BikebhtPostIotRegistDevice : BaseITWebAPIBody {
	
	//
									open var serviceId:String?
    							open var appId:String?
    							open var terminalType:String?
    							open var macAddr:String?
    							open var deviceId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/iotRegistDevice"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/iotRegistDevice"
        	}

	//-------> list
			    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let serviceId_ = self.serviceId;
																					let appId_ = self.appId;
																					let terminalType_ = self.terminalType;
																					let macAddr_ = self.macAddr;
																					let deviceId_ = self.deviceId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikebhtPostIotRegistDevice",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:7,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:7,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:7,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:7,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:7,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:7,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:7,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:7,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:7,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:7,field:"terminalType",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:7,value:terminalType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:7,field:"terminalType",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:7,field:"macAddr",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:7,value:macAddr_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:7,field:"macAddr",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:7,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:7,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:7,field:"deviceId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikebhtPostIotRegistDevice",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikebhtRetIotRegistDevice : BaseITWebAPIBody {
	
	//
												open var deviceSecret:String?
    							open var success:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/iotRegistDevice"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/iotRegistDevice"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											deviceSecret = visitableSource.getValue("deviceSecret")
																											success = visitableSource.getValue("success")
															}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikebhtPostQueryIotDeviceByName : BaseITWebAPIBody {
	
	//
									open var serviceId:String?
    							open var appId:String?
    							open var terminalType:String?
    							open var macAddr:String?
    							open var deviceId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/queryIotDeviceByName"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/queryIotDeviceByName"
        	}

	//-------> list
			    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let serviceId_ = self.serviceId;
																					let appId_ = self.appId;
																					let terminalType_ = self.terminalType;
																					let macAddr_ = self.macAddr;
																					let deviceId_ = self.deviceId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikebhtPostQueryIotDeviceByName",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:7,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:7,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:7,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:7,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:7,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:7,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:7,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:7,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:7,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:7,field:"terminalType",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:7,value:terminalType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:7,field:"terminalType",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:7,field:"macAddr",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:7,value:macAddr_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:7,field:"macAddr",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:7,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:7,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:7,field:"deviceId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikebhtPostQueryIotDeviceByName",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikebhtRetQueryIotDeviceByName : BaseITWebAPIBody {
	
	//
												open var success:String?
    				    		//----->list
			fileprivate var data = [BikebhtIotDeviceInfo]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/queryIotDeviceByName"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/queryIotDeviceByName"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											success = visitableSource.getValue("success")
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( IotDeviceInfo (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addData(subBody:IotDeviceInfo) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [IotDeviceInfo]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class BikebhtIotDeviceInfo : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    							open var deviceName:String?
    							open var deviceSecret:String?
    							open var productKey:String?
    							open var GmtCreate:String?
    							open var GmtModified:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/queryIotDeviceByName"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/queryIotDeviceByName"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		deviceId = visitableSource.getValue("deviceId")
																											deviceName = visitableSource.getValue("deviceName")
																											deviceSecret = visitableSource.getValue("deviceSecret")
																											productKey = visitableSource.getValue("productKey")
																											GmtCreate = visitableSource.getValue("GmtCreate")
																											GmtModified = visitableSource.getValue("GmtModified")
															}

	//-------> list
			    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class BikebhtPostQueryIotDeviceList : BaseITWebAPIBody {
	
	//
									open var serviceId:String?
    							open var appId:String?
    							open var terminalType:String?
    							open var macAddr:String?
    							open var currentPage:String?
    							open var pageSize:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/queryIotDeviceList"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/queryIotDeviceList"
        	}

	//-------> list
			    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let serviceId_ = self.serviceId;
																					let appId_ = self.appId;
																					let terminalType_ = self.terminalType;
																					let macAddr_ = self.macAddr;
																					let currentPage_ = self.currentPage;
																					let pageSize_ = self.pageSize;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikebhtPostQueryIotDeviceList",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:8,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:8,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:8,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:8,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:8,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:8,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:8,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:8,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:8,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:8,field:"terminalType",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:8,value:terminalType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:8,field:"terminalType",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:8,field:"macAddr",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:8,value:macAddr_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:8,field:"macAddr",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:8,field:"currentPage",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:8,value:currentPage_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:8,field:"currentPage",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:8,field:"pageSize",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:8,value:pageSize_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:8,field:"pageSize",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikebhtPostQueryIotDeviceList",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikebhtRetQueryIotDeviceList : BaseITWebAPIBody {
	
	//
												open var success:String?
    				    		//----->list
			fileprivate var data = [BikebhtIotDeviceInfo]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/queryIotDeviceList"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/queryIotDeviceList"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											success = visitableSource.getValue("success")
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( IotDeviceInfo (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addData(subBody:IotDeviceInfo) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [IotDeviceInfo]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class BikebhtIotDeviceInfo : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    							open var deviceName:String?
    							open var deviceSecret:String?
    							open var productKey:String?
    							open var GmtCreate:String?
    							open var GmtModified:String?
    							open var deviceStatus:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/queryIotDeviceList"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/queryIotDeviceList"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		deviceId = visitableSource.getValue("deviceId")
																											deviceName = visitableSource.getValue("deviceName")
																											deviceSecret = visitableSource.getValue("deviceSecret")
																											productKey = visitableSource.getValue("productKey")
																											GmtCreate = visitableSource.getValue("GmtCreate")
																											GmtModified = visitableSource.getValue("GmtModified")
																											deviceStatus = visitableSource.getValue("deviceStatus")
															}

	//-------> list
			    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class BikebhtPostIotCmd : BaseITWebAPIBody {
	
	//
									open var serviceId:String?
    							open var appId:String?
    							open var terminalType:String?
    							open var macAddr:String?
    							open var deviceId:String?
    							open var cmdType:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/iotCmd"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/iotCmd"
        	}

	//-------> list
			    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let serviceId_ = self.serviceId;
																					let appId_ = self.appId;
																					let terminalType_ = self.terminalType;
																					let macAddr_ = self.macAddr;
																					let deviceId_ = self.deviceId;
																					let cmdType_ = self.cmdType;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikebhtPostIotCmd",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:8,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:8,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:8,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:8,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:8,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:8,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:8,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:8,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:8,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:8,field:"terminalType",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:8,value:terminalType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:8,field:"terminalType",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:8,field:"macAddr",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:8,value:macAddr_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:8,field:"macAddr",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:8,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:8,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:8,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:8,field:"cmdType",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:8,value:cmdType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:8,field:"cmdType",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikebhtPostIotCmd",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikebhtRetIotCmd : BaseITWebAPIBody {
	
	//
												open var success:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/iotCmd"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/iotCmd"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											success = visitableSource.getValue("success")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikebhtPostQueryHeartBag : BaseITWebAPIBody {
	
	//
									open var serviceId:String?
    							open var appId:String?
    							open var terminalType:String?
    							open var macAddr:String?
    							open var deviceId:String?
    							open var deviceType:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/queryHeartBag"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/queryHeartBag"
        	}

	//-------> list
			    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let serviceId_ = self.serviceId;
																					let appId_ = self.appId;
																					let terminalType_ = self.terminalType;
																					let macAddr_ = self.macAddr;
																					let deviceId_ = self.deviceId;
																					let deviceType_ = self.deviceType;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikebhtPostQueryHeartBag",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:8,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:8,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:8,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:8,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:8,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:8,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:8,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:8,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:8,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:8,field:"terminalType",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:8,value:terminalType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:8,field:"terminalType",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:8,field:"macAddr",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:8,value:macAddr_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:8,field:"macAddr",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:8,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:8,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:8,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:8,field:"deviceType",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:8,value:deviceType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:8,field:"deviceType",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikebhtPostQueryHeartBag",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikebhtRetQueryHeartBag : BaseITWebAPIBody {
	
	//
												open var success:String?
    							open var deviceId:String?
    							open var devType:String?
    							open var lockStatus:String?
    							open var lifeCycle:String?
    							open var batteryLevel:String?
    							open var signLevel:String?
    							open var macList:String?
    							open var cordinate:String?
    							open var cordType:String?
    							open var hardwareVer:String?
    							open var createTime:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/queryHeartBag"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/queryHeartBag"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											success = visitableSource.getValue("success")
																											deviceId = visitableSource.getValue("deviceId")
																											devType = visitableSource.getValue("devType")
																											lockStatus = visitableSource.getValue("lockStatus")
																											lifeCycle = visitableSource.getValue("lifeCycle")
																											batteryLevel = visitableSource.getValue("batteryLevel")
																											signLevel = visitableSource.getValue("signLevel")
																											macList = visitableSource.getValue("macList")
																											cordinate = visitableSource.getValue("cordinate")
																											cordType = visitableSource.getValue("cordType")
																											hardwareVer = visitableSource.getValue("hardwareVer")
																											createTime = visitableSource.getValue("createTime")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikebhtPostGenerateDeviceId : BaseITWebAPIBody {
	
	//
									open var serviceId:String?
    							open var appId:String?
    							open var terminalType:String?
    							open var devType:String?
    							open var length:String?
    							open var cityCode:String?
    							open var params:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/generateDeviceId"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/generateDeviceId"
        	}

	//-------> list
			    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let serviceId_ = self.serviceId;
																					let appId_ = self.appId;
																					let terminalType_ = self.terminalType;
																					let devType_ = self.devType;
																					let length_ = self.length;
																					let cityCode_ = self.cityCode;
																					let params_ = self.params;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikebhtPostGenerateDeviceId",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:9,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:9,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:9,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:9,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:9,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:9,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:9,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:9,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:9,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:9,field:"terminalType",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:9,value:terminalType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:9,field:"terminalType",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:9,field:"devType",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:9,value:devType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:9,field:"devType",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:9,field:"length",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:9,value:length_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:9,field:"length",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:9,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:9,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:9,field:"cityCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:8,length:9,field:"params",body:self))
				result.append(vo.onFieldValue(.flat,index:8,length:9,value:params_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:8,length:9,field:"params",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BikebhtPostGenerateDeviceId",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikebhtRetGenerateDeviceId : BaseITWebAPIBody {
	
	//
												open var deviceId:String?
    							open var cityCode:String?
    							open var bizExtra:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/generateDeviceId"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikegw/manage/generateDeviceId"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											deviceId = visitableSource.getValue("deviceId")
																											cityCode = visitableSource.getValue("cityCode")
																											bizExtra = visitableSource.getValue("bizExtra")
															}

	//-------> list
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BikebhtPostBHTQueryDevicesTest : BaseITWebAPIBody {
	
	//
						open var appId:String?
    							open var serviceId:String?
    							open var type:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/business/bhtquerydevicesTest"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/business/bhtquerydevicesTest"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let appId_ = secureKeys?["AES"]?.encrypt(original: self.appId) ?? ""
																					let serviceId_ = secureKeys?["AES"]?.encrypt(original: self.serviceId) ?? ""
																					let type_ = self.type;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("appId=" + (appId_ ?? ""))
																					md5.append("&serviceId=" + (serviceId_ ?? ""))
																					md5.append("&type=" + (type_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BikebhtPostBHTQueryDevicesTest",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"serviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"type",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:type_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"type",body:self))
									result.append(vo.onFieldBegin(.flat,index:4,length:4,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:4,length:4,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:4,length:4,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BikebhtPostBHTQueryDevicesTest",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BikebhtRetBHTQueryDevicesTest : BaseITWebAPIBody {
	
	//
												open var datacount:String?
    				    		//----->list
			fileprivate var data = [BikebhtRetBHTQueryDevicesDetailTest]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/business/bhtquerydevicesTest"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/business/bhtquerydevicesTest"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											datacount = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("datacount"))
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( RetBHTQueryDevicesDetailTest (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addData(subBody:RetBHTQueryDevicesDetailTest) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [RetBHTQueryDevicesDetailTest]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class BikebhtRetBHTQueryDevicesDetailTest : BaseITWebAPIBody {
	
	//
						open var cityCode:String?
    							open var deviceId:String?
    							open var deviceName:String?
    							open var coordinate:String?
    							open var coordType:String?
    							open var address:String?
    							open var status:String?
    							open var updatetime:String?
    							open var totalcount:String?
    							open var rentcount:String?
    							open var restorecount:String?
    							open var type:String?
    		
	required public init(){
		super.init()
		self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/business/bhtquerydevicesTest"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "38"
		self.appName_ = "bikebht"
		self.mapping_ = "/api/bikebht/business/bhtquerydevicesTest"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		cityCode = visitableSource.getValue("cityCode")
																											deviceId = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("deviceId"))
																											deviceName = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("deviceName"))
																											coordinate = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("coordinate"))
																											coordType = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("coordType"))
																											address = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("address"))
																											status = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("status"))
																											updatetime = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("updatetime"))
																											totalcount = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("totalcount"))
																											rentcount = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("rentcount"))
																											restorecount = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("restorecount"))
																											type = visitableSource.getValue("type")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}
