import Foundation
import ITWebAPI
// MARK: Factory
open class BizomWebAPIContext : ITWebAPIContext{
	required public init(){}
    open var visitablePair:ITVisitablePair = ITXmlVisitablePair()
    fileprivate var secureKeys = [String:ITSecureKey]()
    open func setSecureKey(_ secureKey:ITSecureKey?) -> ITWebAPIContext?{
        if let secureKey_ = secureKey {
            secureKeys[secureKey_.name] = secureKey_
        }
        return self
    }

    open func getSecureKey(_ keyName:String) -> ITSecureKey? {
        return self.secureKeys[keyName]
    }

    open func getSecureKeys() -> [String:ITSecureKey]? {
        return self.secureKeys
    }

    open func createRequestBody(_ requestMapping:String) -> ITWebAPIBody {
        return self.createBody(type: .requestBody, requestMapping: requestMapping, content: nil, secureKeys: self.secureKeys)
    }
    open func createRequestBody(_ requestMapping:String,content:String?) -> ITWebAPIBody {
        return self.createBody(type: .requestBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
    }
    open func createRequestBody(_ requestMapping:String,content:String?,secureKey:ITSecureKey?) -> ITWebAPIBody{
        if secureKey == nil {
            return self.createBody(type: .requestBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
        }

        return self.createBody(type: .requestBody, requestMapping: requestMapping, content: content, secureKeys: [secureKey!.name:secureKey!])
    }

    open func createResponseBody(_ requestMapping:String) -> ITWebAPIBody {
        return self.createBody(type: .responseBody, requestMapping: requestMapping, content: nil, secureKeys: self.secureKeys)
    }
    open func createResponseBody(_ requestMapping:String,content:String?) -> ITWebAPIBody {
        return self.createBody(type: .responseBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
    }
    open func createResponseBody(_ requestMapping:String,content:String?,secureKey:ITSecureKey?) -> ITWebAPIBody {
        if secureKey == nil {
            return self.createBody(type: .responseBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
        }

        return self.createBody(type: .responseBody, requestMapping: requestMapping, content: content, secureKeys: [secureKey!.name:secureKey!])
    }

    fileprivate enum BodyType{
        case requestBody
        case responseBody
    }

    fileprivate func createBody(type:BodyType,requestMapping:String,content:String?,secureKeys:[String:ITSecureKey]) -> ITWebAPIBody{
        var body:ITWebAPIBody
        switch(requestMapping){
        				case "/api/bizom/activity/createActivity":
				if type == .requestBody {
                    body = BizomPostCreateAcitvity()
                } else {
                    body = BizomRetCreateAcitvity(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bizom/activity/getActivities":
				if type == .requestBody {
                    body = BizomPostGetActivities()
                } else {
                    body = BizomRetGetActivities(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bizom/activity/getUserActivities":
				if type == .requestBody {
                    body = BizomPostGetUserActivities()
                } else {
                    body = BizomRetGetUserActivities(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bizom/oss/getOssAccessKey":
				if type == .requestBody {
                    body = BizomPostAccessKey()
                } else {
                    body = BizomRetAccessKey(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bizom/activity/getNotices":
				if type == .requestBody {
                    body = BizomPostGetNotices()
                } else {
                    body = BizomRetGetNotices(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bizom/activity/getAPPAds":
				if type == .requestBody {
                    body = BizomPostGetAPPAdss()
                } else {
                    body = BizomRetGetAPPAds(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bizom/activity/getActivityConfig":
				if type == .requestBody {
                    body = BizomPostGetActivityConfig()
                } else {
                    body = BizomRetGetActivityConfig(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bizom/games/getGamesLists":
				if type == .requestBody {
                    body = BizomPostGetGamesLists()
                } else {
                    body = BizomRetGetGamesLists(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bizom/games/uploadScore":
				if type == .requestBody {
                    body = BizomPostUploadScore()
                } else {
                    body = BizomRetUploadScore(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bizom/games/listRankUser":
				if type == .requestBody {
                    body = BizomPostListRankUser()
                } else {
                    body = BizomRetListRankUser(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						default:
			body = BaseITWebAPIBody()
        }
        body.context = self
        return body
    }
}


		
open class BizomPostCreateAcitvity : BaseITWebAPIBody {
	
	//
									open var type:String?
    							open var appId:String?
    							open var serId:String?
    							open var title:String?
    							open var content:String?
    							open var lonLat:String?
    							open var faultPart:String?
    							open var faultDetail:String?
    							open var bikeType:String?
    							open var media1:String?
    							open var media2:String?
    							open var media3:String?
    		
	required public init(){
		super.init()
		self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/activity/createActivity"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/activity/createActivity"
        	}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let type_ = secureKeys?["AES"]?.encrypt(original: self.type) ?? ""
																					let appId_ = secureKeys?["AES"]?.encrypt(original: self.appId) ?? ""
																					let serId_ = secureKeys?["AES"]?.encrypt(original: self.serId) ?? ""
																					let title_ = secureKeys?["AES"]?.encrypt(original: self.title) ?? ""
																					let content_ = secureKeys?["AES"]?.encrypt(original: self.content) ?? ""
																					let lonLat_ = self.lonLat;
																					let faultPart_ = self.faultPart;
																					let faultDetail_ = self.faultDetail;
																					let bikeType_ = self.bikeType;
																					let media1_ = self.media1;
																					let media2_ = self.media2;
																					let media3_ = self.media3;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("accessToken=" + (accessToken_ ?? ""))
																					md5.append("&type=" + (type_ ?? ""))
																					md5.append("&appId=" + (appId_ ?? ""))
																					md5.append("&serId=" + (serId_ ?? ""))
																					md5.append("&title=" + (title_ ?? ""))
																					md5.append("&content=" + (content_ ?? ""))
																																																															
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizomPostCreateAcitvity",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:14,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:14,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:14,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:14,field:"type",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:14,value:type_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:14,field:"type",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:14,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:14,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:14,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:14,field:"serId",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:14,value:serId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:14,field:"serId",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:14,field:"title",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:14,value:title_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:14,field:"title",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:14,field:"content",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:14,value:content_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:14,field:"content",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:14,field:"lonLat",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:14,value:lonLat_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:14,field:"lonLat",body:self))
												result.append(vo.onFieldBegin(.flat,index:8,length:14,field:"faultPart",body:self))
				result.append(vo.onFieldValue(.flat,index:8,length:14,value:faultPart_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:8,length:14,field:"faultPart",body:self))
												result.append(vo.onFieldBegin(.flat,index:9,length:14,field:"faultDetail",body:self))
				result.append(vo.onFieldValue(.flat,index:9,length:14,value:faultDetail_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:9,length:14,field:"faultDetail",body:self))
												result.append(vo.onFieldBegin(.flat,index:10,length:14,field:"bikeType",body:self))
				result.append(vo.onFieldValue(.flat,index:10,length:14,value:bikeType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:10,length:14,field:"bikeType",body:self))
												result.append(vo.onFieldBegin(.flat,index:11,length:14,field:"media1",body:self))
				result.append(vo.onFieldValue(.flat,index:11,length:14,value:media1_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:11,length:14,field:"media1",body:self))
												result.append(vo.onFieldBegin(.flat,index:12,length:14,field:"media2",body:self))
				result.append(vo.onFieldValue(.flat,index:12,length:14,value:media2_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:12,length:14,field:"media2",body:self))
												result.append(vo.onFieldBegin(.flat,index:13,length:14,field:"media3",body:self))
				result.append(vo.onFieldValue(.flat,index:13,length:14,value:media3_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:13,length:14,field:"media3",body:self))
									result.append(vo.onFieldBegin(.flat,index:14,length:14,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:14,length:14,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:14,length:14,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BizomPostCreateAcitvity",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizomRetCreateAcitvity : BaseITWebAPIBody {
	
	//
												open var actId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/activity/createActivity"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/activity/createActivity"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											actId = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("actId"))
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizomPostGetActivities : BaseITWebAPIBody {
	
	//
						open var type:String?
    							open var appId:String?
    							open var serId:String?
    							open var title:String?
    							open var start:String?
    							open var limit:String?
    		
	required public init(){
		super.init()
		self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/activity/getActivities"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/activity/getActivities"
        	}

	//-------> list
			    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let type_ = self.type;
																					let appId_ = secureKeys?["AES"]?.encrypt(original: self.appId) ?? ""
																					let serId_ = secureKeys?["AES"]?.encrypt(original: self.serId) ?? ""
																					let title_ = secureKeys?["AES"]?.encrypt(original: self.title) ?? ""
																					let start_ = self.start;
																					let limit_ = self.limit;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("type=" + (type_ ?? ""))
																					md5.append("&appId=" + (appId_ ?? ""))
																					md5.append("&serId=" + (serId_ ?? ""))
																					md5.append("&title=" + (title_ ?? ""))
																					md5.append("&start=" + (start_ ?? ""))
																					md5.append("&limit=" + (limit_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizomPostGetActivities",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:7,field:"type",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:7,value:type_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:7,field:"type",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:7,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:7,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:7,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:7,field:"serId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:7,value:serId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:7,field:"serId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:7,field:"title",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:7,value:title_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:7,field:"title",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:7,field:"start",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:7,value:start_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:7,field:"start",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:7,field:"limit",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:7,value:limit_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:7,field:"limit",body:self))
									result.append(vo.onFieldBegin(.flat,index:7,length:7,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:7,length:7,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:7,length:7,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BizomPostGetActivities",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizomRetGetActivities : BaseITWebAPIBody {
	
	//
												open var datacount:String?
    				    		//----->list
			fileprivate var data = [BizomRetGetActivitiesDetail]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/activity/getActivities"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/activity/getActivities"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											datacount = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("datacount"))
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( RetGetActivitiesDetail (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addData(subBody:RetGetActivitiesDetail) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [RetGetActivitiesDetail]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class BizomRetGetActivitiesDetail : BaseITWebAPIBody {
	
	//
						open var actId:String?
    							open var userId:String?
    							open var type:String?
    							open var appId:String?
    							open var serId:String?
    							open var title:String?
    							open var content:String?
    							open var reply:String?
    							open var createTime:String?
    							open var media1:String?
    							open var media2:String?
    							open var media3:String?
    							open var linkURL:String?
    		
	required public init(){
		super.init()
		self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/activity/getActivities"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/activity/getActivities"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		actId = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("actId"))
																											userId = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("userId"))
																											type = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("type"))
																											appId = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("appId"))
																											serId = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("serId"))
																											title = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("title"))
																											content = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("content"))
																											reply = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("reply"))
																											createTime = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("createTime"))
																											media1 = visitableSource.getValue("media1")
																											media2 = visitableSource.getValue("media2")
																											media3 = visitableSource.getValue("media3")
																											linkURL = visitableSource.getValue("linkURL")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class BizomPostGetUserActivities : BaseITWebAPIBody {
	
	//
									open var type:String?
    							open var appId:String?
    							open var serId:String?
    							open var title:String?
    							open var start:String?
    							open var limit:String?
    		
	required public init(){
		super.init()
		self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/activity/getUserActivities"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/activity/getUserActivities"
        	}

	//-------> list
			    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let type_ = self.type;
																					let appId_ = secureKeys?["AES"]?.encrypt(original: self.appId) ?? ""
																					let serId_ = secureKeys?["AES"]?.encrypt(original: self.serId) ?? ""
																					let title_ = secureKeys?["AES"]?.encrypt(original: self.title) ?? ""
																					let start_ = self.start;
																					let limit_ = self.limit;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("accessToken=" + (accessToken_ ?? ""))
																					md5.append("&type=" + (type_ ?? ""))
																					md5.append("&appId=" + (appId_ ?? ""))
																					md5.append("&serId=" + (serId_ ?? ""))
																					md5.append("&title=" + (title_ ?? ""))
																					md5.append("&start=" + (start_ ?? ""))
																					md5.append("&limit=" + (limit_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizomPostGetUserActivities",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:8,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:8,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:8,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:8,field:"type",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:8,value:type_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:8,field:"type",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:8,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:8,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:8,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:8,field:"serId",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:8,value:serId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:8,field:"serId",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:8,field:"title",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:8,value:title_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:8,field:"title",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:8,field:"start",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:8,value:start_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:8,field:"start",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:8,field:"limit",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:8,value:limit_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:8,field:"limit",body:self))
									result.append(vo.onFieldBegin(.flat,index:8,length:8,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:8,length:8,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:8,length:8,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BizomPostGetUserActivities",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizomRetGetUserActivities : BaseITWebAPIBody {
	
	//
												open var datacount:String?
    				    		//----->list
			fileprivate var data = [BizomRetGetUserActivitiesDetail]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/activity/getUserActivities"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/activity/getUserActivities"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											datacount = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("datacount"))
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( RetGetUserActivitiesDetail (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addData(subBody:RetGetUserActivitiesDetail) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [RetGetUserActivitiesDetail]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class BizomRetGetUserActivitiesDetail : BaseITWebAPIBody {
	
	//
						open var actId:String?
    							open var userId:String?
    							open var type:String?
    							open var appId:String?
    							open var serId:String?
    							open var title:String?
    							open var content:String?
    							open var reply:String?
    							open var createTime:String?
    							open var lonLat:String?
    							open var faultPart:String?
    							open var faultDetail:String?
    							open var media1:String?
    							open var media2:String?
    							open var media3:String?
    							open var linkURL:String?
    		
	required public init(){
		super.init()
		self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/activity/getUserActivities"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/activity/getUserActivities"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		actId = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("actId"))
																											userId = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("userId"))
																											type = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("type"))
																											appId = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("appId"))
																											serId = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("serId"))
																											title = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("title"))
																											content = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("content"))
																											reply = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("reply"))
																											createTime = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("createTime"))
																											lonLat = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("lonLat"))
																											faultPart = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("faultPart"))
																											faultDetail = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("faultDetail"))
																											media1 = visitableSource.getValue("media1")
																											media2 = visitableSource.getValue("media2")
																											media3 = visitableSource.getValue("media3")
																											linkURL = visitableSource.getValue("linkURL")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class BizomPostAccessKey : BaseITWebAPIBody {
	
	//
									open var appId:String?
    							open var serId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/oss/getOssAccessKey"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/oss/getOssAccessKey"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let appId_ = secureKeys?["AES"]?.encrypt(original: self.appId) ?? ""
																					let serId_ = secureKeys?["AES"]?.encrypt(original: self.serId) ?? ""
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("accessToken=" + (accessToken_ ?? ""))
																					md5.append("&appId=" + (appId_ ?? ""))
																					md5.append("&serId=" + (serId_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizomPostAccessKey",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"serId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:serId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"serId",body:self))
									result.append(vo.onFieldBegin(.flat,index:4,length:4,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:4,length:4,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:4,length:4,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BizomPostAccessKey",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizomRetAccessKey : BaseITWebAPIBody {
	
	//
												open var accessKeyID:String?
    							open var accessKeySecret:String?
    							open var bucketName:String?
    							open var endPoint:String?
    		
	required public init(){
		super.init()
		self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/oss/getOssAccessKey"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/oss/getOssAccessKey"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											accessKeyID = visitableSource.getValue("accessKeyID")
																											accessKeySecret = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("accessKeySecret"))
																											bucketName = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("bucketName"))
																											endPoint = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("endPoint"))
															}

	//-------> list
			    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizomPostGetNotices : BaseITWebAPIBody {
	
	//
						open var appId:String?
    							open var serId:String?
    							open var start:String?
    							open var limit:String?
    		
	required public init(){
		super.init()
		self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/activity/getNotices"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/activity/getNotices"
        	}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let appId_ = self.appId;
																					let serId_ = self.serId;
																					let start_ = self.start;
																					let limit_ = self.limit;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("appId=" + (appId_ ?? ""))
																					md5.append("&serId=" + (serId_ ?? ""))
																					md5.append("&start=" + (start_ ?? ""))
																					md5.append("&limit=" + (limit_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizomPostGetNotices",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:5,field:"serId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:5,value:serId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:5,field:"serId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:5,field:"start",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:5,value:start_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:5,field:"start",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:5,field:"limit",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:5,value:limit_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:5,field:"limit",body:self))
									result.append(vo.onFieldBegin(.flat,index:5,length:5,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:5,length:5,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:5,length:5,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BizomPostGetNotices",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizomRetGetNotices : BaseITWebAPIBody {
	
	//
												open var datacount:String?
    				    		//----->list
			fileprivate var data = [BizomRetGetNoticesDetail]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/activity/getNotices"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/activity/getNotices"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											datacount = visitableSource.getValue("datacount")
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( RetGetNoticesDetail (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addData(subBody:RetGetNoticesDetail) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [RetGetNoticesDetail]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class BizomRetGetNoticesDetail : BaseITWebAPIBody {
	
	//
						open var noticeId:String?
    							open var appId:String?
    							open var serId:String?
    							open var title:String?
    							open var content:String?
    							open var createTime:String?
    							open var media1:String?
    							open var media2:String?
    							open var media3:String?
    							open var linkURL:String?
    		
	required public init(){
		super.init()
		self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/activity/getNotices"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/activity/getNotices"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		noticeId = visitableSource.getValue("noticeId")
																											appId = visitableSource.getValue("appId")
																											serId = visitableSource.getValue("serId")
																											title = visitableSource.getValue("title")
																											content = visitableSource.getValue("content")
																											createTime = visitableSource.getValue("createTime")
																											media1 = visitableSource.getValue("media1")
																											media2 = visitableSource.getValue("media2")
																											media3 = visitableSource.getValue("media3")
																											linkURL = visitableSource.getValue("linkURL")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class BizomPostGetAPPAdss : BaseITWebAPIBody {
	
	//
						open var appId:String?
    							open var serId:String?
    							open var type:String?
    		
	required public init(){
		super.init()
		self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/activity/getAPPAds"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/activity/getAPPAds"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let appId_ = self.appId;
																					let serId_ = self.serId;
																					let type_ = self.type;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("appId=" + (appId_ ?? ""))
																					md5.append("&serId=" + (serId_ ?? ""))
																					
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizomPostGetAPPAdss",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"serId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:serId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"serId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"type",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:type_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"type",body:self))
									result.append(vo.onFieldBegin(.flat,index:4,length:4,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:4,length:4,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:4,length:4,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BizomPostGetAPPAdss",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizomRetGetAPPAds : BaseITWebAPIBody {
	
	//
												open var title:String?
    							open var content:String?
    							open var media1:String?
    							open var linkURL:String?
    		
	required public init(){
		super.init()
		self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/activity/getAPPAds"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/activity/getAPPAds"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											title = visitableSource.getValue("title")
																											content = visitableSource.getValue("content")
																											media1 = visitableSource.getValue("media1")
																											linkURL = visitableSource.getValue("linkURL")
															}

	//-------> list
			    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizomPostGetActivityConfig : BaseITWebAPIBody {
	
	//
						open var appId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/activity/getActivityConfig"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/activity/getActivityConfig"
        	}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let appId_ = self.appId;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("appId=" + (appId_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizomPostGetActivityConfig",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"appId",body:self))
									result.append(vo.onFieldBegin(.flat,index:2,length:2,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:2,length:2,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:2,length:2,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BizomPostGetActivityConfig",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizomRetGetActivityConfig : BaseITWebAPIBody {
	
	//
						open var title:String?
    							open var summary:String?
    							open var iconURL:String?
    							open var linkURL:String?
    							open var advertURL:String?
    		
	required public init(){
		super.init()
		self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/activity/getActivityConfig"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/activity/getActivityConfig"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		title = visitableSource.getValue("title")
																											summary = visitableSource.getValue("summary")
																											iconURL = visitableSource.getValue("iconURL")
																											linkURL = visitableSource.getValue("linkURL")
																											advertURL = visitableSource.getValue("advertURL")
															}

	//-------> list
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizomPostGetGamesLists : BaseITWebAPIBody {
	
	//
						open var type:String?
    							open var appId:String?
    							open var serId:String?
    							open var start:String?
    							open var limit:String?
    		
	required public init(){
		super.init()
		self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/games/getGamesLists"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/games/getGamesLists"
        	}

	//-------> list
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let type_ = self.type;
																					let appId_ = self.appId;
																					let serId_ = self.serId;
																					let start_ = self.start;
																					let limit_ = self.limit;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizomPostGetGamesLists",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:6,field:"type",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:6,value:type_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:6,field:"type",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:6,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:6,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:6,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:6,field:"serId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:6,value:serId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:6,field:"serId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:6,field:"start",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:6,value:start_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:6,field:"start",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:6,field:"limit",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:6,value:limit_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:6,field:"limit",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizomPostGetGamesLists",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizomRetGetGamesLists : BaseITWebAPIBody {
	
	//
												open var datacount:String?
    				    		//----->list
			fileprivate var data = [BizomRetGetGames]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/games/getGamesLists"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/games/getGamesLists"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											datacount = visitableSource.getValue("datacount")
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( RetGetGames (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addData(subBody:RetGetGames) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [RetGetGames]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class BizomRetGetGames : BaseITWebAPIBody {
	
	//
						open var id:String?
    							open var type:String?
    							open var appId:String?
    							open var serId:String?
    							open var title:String?
    							open var content:String?
    							open var createTime:String?
    							open var media1:String?
    							open var media2:String?
    							open var media3:String?
    							open var linkURL:String?
    		
	required public init(){
		super.init()
		self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/games/getGamesLists"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/games/getGamesLists"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		id = visitableSource.getValue("id")
																											type = visitableSource.getValue("type")
																											appId = visitableSource.getValue("appId")
																											serId = visitableSource.getValue("serId")
																											title = visitableSource.getValue("title")
																											content = visitableSource.getValue("content")
																											createTime = visitableSource.getValue("createTime")
																											media1 = visitableSource.getValue("media1")
																											media2 = visitableSource.getValue("media2")
																											media3 = visitableSource.getValue("media3")
																											linkURL = visitableSource.getValue("linkURL")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class BizomPostUploadScore : BaseITWebAPIBody {
	
	//
									open var gameId:String?
    							open var score:String?
    							open var scoreMark:String?
    		
	required public init(){
		super.init()
		self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/games/uploadScore"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/games/uploadScore"
        	}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let gameId_ = self.gameId;
																					let score_ = self.score;
																					let scoreMark_ = self.scoreMark;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizomPostUploadScore",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:5,field:"gameId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:5,value:gameId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:5,field:"gameId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:5,field:"score",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:5,value:score_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:5,field:"score",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:5,field:"scoreMark",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:5,value:scoreMark_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:5,field:"scoreMark",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizomPostUploadScore",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizomRetUploadScore : BaseITWebAPIBody {
	
	//
												open var bizStatus:String?
    							open var userId:String?
    							open var phoneNum:String?
    							open var rank:String?
    							open var score:String?
    							open var scoreMark:String?
    							open var nickName:String?
    							open var avatar:String?
    		
	required public init(){
		super.init()
		self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/games/uploadScore"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/games/uploadScore"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											bizStatus = visitableSource.getValue("bizStatus")
																											userId = visitableSource.getValue("userId")
																											phoneNum = visitableSource.getValue("phoneNum")
																											rank = visitableSource.getValue("rank")
																											score = visitableSource.getValue("score")
																											scoreMark = visitableSource.getValue("scoreMark")
																											nickName = visitableSource.getValue("nickName")
																											avatar = visitableSource.getValue("avatar")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizomPostListRankUser : BaseITWebAPIBody {
	
	//
									open var gameId:String?
    							open var start:String?
    							open var limit:String?
    		
	required public init(){
		super.init()
		self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/games/listRankUser"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/games/listRankUser"
        	}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let gameId_ = self.gameId;
																					let start_ = self.start;
																					let limit_ = self.limit;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizomPostListRankUser",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:5,field:"gameId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:5,value:gameId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:5,field:"gameId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:5,field:"start",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:5,value:start_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:5,field:"start",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:5,field:"limit",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:5,value:limit_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:5,field:"limit",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizomPostListRankUser",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizomRetListRankUser : BaseITWebAPIBody {
	
	//
												open var bizStatus:String?
    							open var datacount:String?
    				    		//----->list
			fileprivate var data = [BizomRankUserData]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/games/listRankUser"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/games/listRankUser"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											bizStatus = visitableSource.getValue("bizStatus")
																											datacount = visitableSource.getValue("datacount")
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( RankUserData (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    		    			    open func addData(subBody:RankUserData) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [RankUserData]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																													
open class BizomRankUserData : BaseITWebAPIBody {
	
	//
						open var userId:String?
    							open var phoneNum:String?
    							open var rank:String?
    							open var score:String?
    							open var scoreMark:String?
    							open var nickName:String?
    							open var avatar:String?
    		
	required public init(){
		super.init()
		self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/games/listRankUser"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "23"
		self.appName_ = "bizom"
		self.mapping_ = "/api/bizom/games/listRankUser"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		userId = visitableSource.getValue("userId")
																											phoneNum = visitableSource.getValue("phoneNum")
																											rank = visitableSource.getValue("rank")
																											score = visitableSource.getValue("score")
																											scoreMark = visitableSource.getValue("scoreMark")
																											nickName = visitableSource.getValue("nickName")
																											avatar = visitableSource.getValue("avatar")
															}

	//-------> list
			    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}
