import Foundation
import ITWebAPI
// MARK: Factory
open class BizpayWebAPIContext : ITWebAPIContext{
	required public init(){}
    open var visitablePair:ITVisitablePair = ITXmlVisitablePair()
    open var secureKeys = [String:ITSecureKey]()
    open func setSecureKey(_ secureKey:ITSecureKey?) -> ITWebAPIContext?{
        if let secureKey_ = secureKey {
            secureKeys[secureKey_.name] = secureKey_
        }
        return self
    }

    open func getSecureKey(_ keyName:String) -> ITSecureKey? {
        return self.secureKeys[keyName]
    }

    open func getSecureKeys() -> [String:ITSecureKey]? {
        return self.secureKeys
    }

    open func createRequestBody(_ requestMapping:String) -> ITWebAPIBody {
        return self.createBody(type: .requestBody, requestMapping: requestMapping, content: nil, secureKeys: self.secureKeys)
    }
    open func createRequestBody(_ requestMapping:String,content:String?) -> ITWebAPIBody {
        return self.createBody(type: .requestBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
    }
    open func createRequestBody(_ requestMapping:String,content:String?,secureKey:ITSecureKey?) -> ITWebAPIBody{
        if secureKey == nil {
            return self.createBody(type: .requestBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
        }

        return self.createBody(type: .requestBody, requestMapping: requestMapping, content: content, secureKeys: [secureKey!.name:secureKey!])
    }

    open func createResponseBody(_ requestMapping:String) -> ITWebAPIBody {
        return self.createBody(type: .responseBody, requestMapping: requestMapping, content: nil, secureKeys: self.secureKeys)
    }
    open func createResponseBody(_ requestMapping:String,content:String?) -> ITWebAPIBody {
        return self.createBody(type: .responseBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
    }
    open func createResponseBody(_ requestMapping:String,content:String?,secureKey:ITSecureKey?) -> ITWebAPIBody {
        if secureKey == nil {
            return self.createBody(type: .responseBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
        }

        return self.createBody(type: .responseBody, requestMapping: requestMapping, content: content, secureKeys: [secureKey!.name:secureKey!])
    }

    open enum BodyType{
        case requestBody
        case responseBody
    }

    open func createBody(type:BodyType,requestMapping:String,content:String?,secureKeys:[String:ITSecureKey]) -> ITWebAPIBody{
        var body:ITWebAPIBody
        switch(requestMapping){
        				case "/api/bizpay/payment/createOrder":
				if type == .requestBody {
                    body = BizpayPostCreateOrder()
                } else {
                    body = BizpayRetCreateOrder(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bizpay/payment/getOrder":
				if type == .requestBody {
                    body = BizpayPostGetOrder()
                } else {
                    body = BizpayRetGetOrder(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bizpay/payment/getCharge":
				if type == .requestBody {
                    body = BizpayPostGetCharge()
                } else {
                    body = BizpayRetGetCharge(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bizpay/payment/refund":
				if type == .requestBody {
                    body = BizpayPostRefund()
                } else {
                    body = BizpayRetRefund(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bizpay/payment/checkOrder":
				if type == .requestBody {
                    body = BizpayPostCheckOrder()
                } else {
                    body = BizpayRetCheckOrder(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bizpay/payment/getOrders":
				if type == .requestBody {
                    body = BizpayPostGetOrders()
                } else {
                    body = BizpayRetGetOrders(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bizpay/payment/addRefundProgress":
				if type == .requestBody {
                    body = BizpayPostAddRefundProgress()
                } else {
                    body = BizpayRetAddRefundProgress(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bizpay/payment/getUserRefundProgress":
				if type == .requestBody {
                    body = BizpayPostGetUserRefundProgress()
                } else {
                    body = BizpayRetGetUserRefundProgress(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bizpay/payment/modifyOrderStatus":
				if type == .requestBody {
                    body = BizpayPostModifyOrderStatus()
                } else {
                    body = BizpayRetModifyOrderStatus(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bizpay/payment/cancelRefund":
				if type == .requestBody {
                    body = BizpayPostCancelRefund()
                } else {
                    body = BizpayRetCancelRefund(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bizpay/payment/queryAllOrderStatus":
				if type == .requestBody {
                    body = BizpayPostQuertAllOrderStatus()
                } else {
                    body = BizpayRetQueryAllOrderStatus(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bizpay/payment/finishOrder":
				if type == .requestBody {
                    body = BizpayPostFinishOrder()
                } else {
                    body = BizpayRetFinishOrder(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/bizpay/payment/updateOrderCTime":
				if type == .requestBody {
                    body = BizpayPostUpdateOrderCTime()
                } else {
                    body = BizpayRetUpdateOrderCTime(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						default:
			body = BaseITWebAPIBody()
        }
        body.context = self
        return body
    }
}


		
open class BizpayPostCreateOrder : BaseITWebAPIBody {
	
	//
									open var appId:String?
    							open var subject:String?
    							open var body:String?
    							open var money:String?
    							open var orderType:String?
    							open var orderNO:String?
    							open var extra:String?
    							open var serviceId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/createOrder"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/createOrder"
        	}

	//-------> list
			    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let appId_ = secureKeys?["AES"]?.encrypt(original: self.appId) ?? ""
																					let subject_ = secureKeys?["AES"]?.encrypt(original: self.subject) ?? ""
																					let body_ = secureKeys?["AES"]?.encrypt(original: self.body) ?? ""
																					let money_ = secureKeys?["AES"]?.encrypt(original: self.money) ?? ""
																					let orderType_ = secureKeys?["AES"]?.encrypt(original: self.orderType) ?? ""
																					let orderNO_ = secureKeys?["AES"]?.encrypt(original: self.orderNO) ?? ""
																					let extra_ = secureKeys?["AES"]?.encrypt(original: self.extra) ?? ""
																					let serviceId_ = self.serviceId;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("accessToken=" + (accessToken_ ?? ""))
																					md5.append("&appId=" + (appId_ ?? ""))
																					md5.append("&subject=" + (subject_ ?? ""))
																					md5.append("&body=" + (body_ ?? ""))
																					md5.append("&money=" + (money_ ?? ""))
																					md5.append("&orderType=" + (orderType_ ?? ""))
																					md5.append("&orderNO=" + (orderNO_ ?? ""))
																					md5.append("&extra=" + (extra_ ?? ""))
																					
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizpayPostCreateOrder",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:10,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:10,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:10,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:10,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:10,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:10,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:10,field:"subject",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:10,value:subject_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:10,field:"subject",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:10,field:"body",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:10,value:body_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:10,field:"body",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:10,field:"money",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:10,value:money_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:10,field:"money",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:10,field:"orderType",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:10,value:orderType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:10,field:"orderType",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:10,field:"orderNO",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:10,value:orderNO_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:10,field:"orderNO",body:self))
												result.append(vo.onFieldBegin(.flat,index:8,length:10,field:"extra",body:self))
				result.append(vo.onFieldValue(.flat,index:8,length:10,value:extra_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:8,length:10,field:"extra",body:self))
												result.append(vo.onFieldBegin(.flat,index:9,length:10,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:9,length:10,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:9,length:10,field:"serviceId",body:self))
									result.append(vo.onFieldBegin(.flat,index:10,length:10,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:10,length:10,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:10,length:10,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BizpayPostCreateOrder",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizpayRetCreateOrder : BaseITWebAPIBody {
	
	//
												open var orderId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/createOrder"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/createOrder"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											orderId = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("orderId"))
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizpayPostGetOrder : BaseITWebAPIBody {
	
	//
									open var orderId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/getOrder"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/getOrder"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let orderId_ = secureKeys?["AES"]?.encrypt(original: self.orderId) ?? ""
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("accessToken=" + (accessToken_ ?? ""))
																					md5.append("&orderId=" + (orderId_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizpayPostGetOrder",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"orderId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:orderId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"orderId",body:self))
									result.append(vo.onFieldBegin(.flat,index:3,length:3,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:3,length:3,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:3,length:3,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BizpayPostGetOrder",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizpayRetGetOrder : BaseITWebAPIBody {
	
	//
												open var userId:String?
    							open var serviceId:String?
    							open var subject:String?
    							open var body:String?
    							open var orderID:String?
    							open var orderNo:String?
    							open var orderStatus:String?
    							open var orderMoney:String?
    							open var beforeDisMoney:String?
    							open var couponId:String?
    							open var orderType:String?
    							open var createTime:String?
    							open var paidTime:String?
    							open var refundedTime:String?
    							open var refundFlag:String?
    		
	required public init(){
		super.init()
		self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/getOrder"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/getOrder"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											userId = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("userId"))
																											serviceId = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("serviceId"))
																											subject = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("subject"))
																											body = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("body"))
																											orderID = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("orderID"))
																											orderNo = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("orderNo"))
																											orderStatus = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("orderStatus"))
																											orderMoney = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("orderMoney"))
																											beforeDisMoney = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("beforeDisMoney"))
																											couponId = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("couponId"))
																											orderType = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("orderType"))
																											createTime = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("createTime"))
																											paidTime = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("paidTime"))
																											refundedTime = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("refundedTime"))
																											refundFlag = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("refundFlag"))
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizpayPostGetCharge : BaseITWebAPIBody {
	
	//
									open var orderId:String?
    							open var channel:String?
    							open var openId:String?
    							open var money:String?
    							open var callbackURL:String?
    							open var couponId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/getCharge"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/getCharge"
        	}

	//-------> list
			    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let orderId_ = secureKeys?["AES"]?.encrypt(original: self.orderId) ?? ""
																					let channel_ = secureKeys?["AES"]?.encrypt(original: self.channel) ?? ""
																					let openId_ = secureKeys?["AES"]?.encrypt(original: self.openId) ?? ""
																					let money_ = self.money;
																					let callbackURL_ = self.callbackURL;
																					let couponId_ = self.couponId;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("accessToken=" + (accessToken_ ?? ""))
																					md5.append("&orderId=" + (orderId_ ?? ""))
																					md5.append("&channel=" + (channel_ ?? ""))
																																										
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizpayPostGetCharge",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:8,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:8,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:8,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:8,field:"orderId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:8,value:orderId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:8,field:"orderId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:8,field:"channel",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:8,value:channel_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:8,field:"channel",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:8,field:"openId",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:8,value:openId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:8,field:"openId",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:8,field:"money",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:8,value:money_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:8,field:"money",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:8,field:"callbackURL",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:8,value:callbackURL_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:8,field:"callbackURL",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:8,field:"couponId",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:8,value:couponId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:8,field:"couponId",body:self))
									result.append(vo.onFieldBegin(.flat,index:8,length:8,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:8,length:8,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:8,length:8,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BizpayPostGetCharge",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizpayRetGetCharge : BaseITWebAPIBody {
	
	//
												open var chargeStatus:String?
    							open var chargeData:String?
    		
	required public init(){
		super.init()
		self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/getCharge"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/getCharge"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											chargeStatus = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("chargeStatus"))
																											chargeData = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("chargeData"))
															}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizpayPostRefund : BaseITWebAPIBody {
	
	//
									open var orderId:String?
    							open var remark:String?
    		
	required public init(){
		super.init()
		self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/refund"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/refund"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let orderId_ = secureKeys?["AES"]?.encrypt(original: self.orderId) ?? ""
																					let remark_ = secureKeys?["AES"]?.encrypt(original: self.remark) ?? ""
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("accessToken=" + (accessToken_ ?? ""))
																					md5.append("&orderId=" + (orderId_ ?? ""))
																					md5.append("&remark=" + (remark_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizpayPostRefund",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"orderId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:orderId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"orderId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"remark",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:remark_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"remark",body:self))
									result.append(vo.onFieldBegin(.flat,index:4,length:4,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:4,length:4,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:4,length:4,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BizpayPostRefund",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizpayRetRefund : BaseITWebAPIBody {
	
	//
						open var reqStatus:String?
    								
	required public init(){
		super.init()
		self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/refund"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/refund"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		reqStatus = visitableSource.getValue("reqStatus")
																											retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizpayPostCheckOrder : BaseITWebAPIBody {
	
	//
									open var orderId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/checkOrder"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/checkOrder"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let orderId_ = secureKeys?["AES"]?.encrypt(original: self.orderId) ?? ""
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("accessToken=" + (accessToken_ ?? ""))
																					md5.append("&orderId=" + (orderId_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizpayPostCheckOrder",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"orderId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:orderId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"orderId",body:self))
									result.append(vo.onFieldBegin(.flat,index:3,length:3,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:3,length:3,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:3,length:3,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BizpayPostCheckOrder",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizpayRetCheckOrder : BaseITWebAPIBody {
	
	//
												open var orderStatus:String?
    							open var orderType:String?
    							open var paidTime:String?
    							open var chargeChannel:String?
    							open var couponId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/checkOrder"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/checkOrder"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											orderStatus = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("orderStatus"))
																											orderType = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("orderType"))
																											paidTime = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("paidTime"))
																											chargeChannel = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("chargeChannel"))
																											couponId = visitableSource.getValue("couponId")
															}

	//-------> list
			    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizpayPostGetOrders : BaseITWebAPIBody {
	
	//
									open var ordertype:String?
    							open var orderStatus:String?
    							open var start:String?
    							open var limit:String?
    		
	required public init(){
		super.init()
		self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/getOrders"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/getOrders"
        	}

	//-------> list
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let ordertype_ = self.ordertype;
																					let orderStatus_ = self.orderStatus;
																					let start_ = self.start;
																					let limit_ = self.limit;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("accessToken=" + (accessToken_ ?? ""))
																					md5.append("&ordertype=" + (ordertype_ ?? ""))
																					md5.append("&orderStatus=" + (orderStatus_ ?? ""))
																					md5.append("&start=" + (start_ ?? ""))
																					md5.append("&limit=" + (limit_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizpayPostGetOrders",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:6,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:6,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:6,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:6,field:"ordertype",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:6,value:ordertype_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:6,field:"ordertype",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:6,field:"orderStatus",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:6,value:orderStatus_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:6,field:"orderStatus",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:6,field:"start",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:6,value:start_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:6,field:"start",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:6,field:"limit",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:6,value:limit_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:6,field:"limit",body:self))
									result.append(vo.onFieldBegin(.flat,index:6,length:6,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:6,length:6,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:6,length:6,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BizpayPostGetOrders",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizpayRetGetOrders : BaseITWebAPIBody {
	
	//
												open var datacount:String?
    				    		//----->list
			fileprivate var data = [BizpayPayOrderInfo]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/getOrders"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/getOrders"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											datacount = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("datacount"))
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( PayOrderInfo (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addData(subBody:PayOrderInfo) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [PayOrderInfo]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class BizpayPayOrderInfo : BaseITWebAPIBody {
	
	//
						open var orderId:String?
    							open var userId:String?
    							open var subject:String?
    							open var body:String?
    							open var orderNo:String?
    							open var orderStatus:String?
    							open var orderMoney:String?
    							open var orderType:String?
    							open var createTime:String?
    							open var paidTime:String?
    							open var refundedTime:String?
    							open var refundFlag:String?
    							open var posId:String?
    							open var carNum:String?
    		
	required public init(){
		super.init()
		self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/getOrders"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/getOrders"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		orderId = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("orderId"))
																											userId = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("userId"))
																											subject = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("subject"))
																											body = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("body"))
																											orderNo = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("orderNo"))
																											orderStatus = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("orderStatus"))
																											orderMoney = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("orderMoney"))
																											orderType = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("orderType"))
																											createTime = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("createTime"))
																											paidTime = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("paidTime"))
																											refundedTime = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("refundedTime"))
																											refundFlag = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("refundFlag"))
																											posId = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("posId"))
																											carNum = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("carNum"))
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class BizpayPostAddRefundProgress : BaseITWebAPIBody {
	
	//
						open var userId:String?
    							open var orderId:String?
    							open var executeTime:String?
    							open var refundStatus:String?
    							open var refundProgress:String?
    		
	required public init(){
		super.init()
		self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/addRefundProgress"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/addRefundProgress"
        	}

	//-------> list
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let userId_ = self.userId;
																					let orderId_ = self.orderId;
																					let executeTime_ = self.executeTime;
																					let refundStatus_ = self.refundStatus;
																					let refundProgress_ = self.refundProgress;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizpayPostAddRefundProgress",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:6,field:"userId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:6,value:userId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:6,field:"userId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:6,field:"orderId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:6,value:orderId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:6,field:"orderId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:6,field:"executeTime",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:6,value:executeTime_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:6,field:"executeTime",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:6,field:"refundStatus",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:6,value:refundStatus_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:6,field:"refundStatus",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:6,field:"refundProgress",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:6,value:refundProgress_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:6,field:"refundProgress",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizpayPostAddRefundProgress",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizpayRetAddRefundProgress : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/addRefundProgress"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/addRefundProgress"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizpayPostGetUserRefundProgress : BaseITWebAPIBody {
	
	//
						open var userId:String?
    							open var orderId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/getUserRefundProgress"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/getUserRefundProgress"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let userId_ = self.userId;
																					let orderId_ = self.orderId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizpayPostGetUserRefundProgress",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"userId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:userId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"userId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"orderId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:orderId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"orderId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizpayPostGetUserRefundProgress",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizpayRetGetUserRefundProgress : BaseITWebAPIBody {
	
	//
						open var refundStatus:String?
    							open var refundParms:String?
    								
	required public init(){
		super.init()
		self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/getUserRefundProgress"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/getUserRefundProgress"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		refundStatus = visitableSource.getValue("refundStatus")
																											refundParms = visitableSource.getValue("refundParms")
																											retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizpayPostModifyOrderStatus : BaseITWebAPIBody {
	
	//
						open var userId:String?
    							open var orderId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/modifyOrderStatus"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/modifyOrderStatus"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let userId_ = self.userId;
																					let orderId_ = self.orderId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizpayPostModifyOrderStatus",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"userId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:userId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"userId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"orderId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:orderId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"orderId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizpayPostModifyOrderStatus",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizpayRetModifyOrderStatus : BaseITWebAPIBody {
	
	//
						open var successCode:String?
    								
	required public init(){
		super.init()
		self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/modifyOrderStatus"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/modifyOrderStatus"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		successCode = visitableSource.getValue("successCode")
																											retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizpayPostCancelRefund : BaseITWebAPIBody {
	
	//
						open var userId:String?
    							open var orderId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/cancelRefund"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/cancelRefund"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let userId_ = self.userId;
																					let orderId_ = self.orderId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizpayPostCancelRefund",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"userId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:userId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"userId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"orderId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:orderId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"orderId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizpayPostCancelRefund",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizpayRetCancelRefund : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/cancelRefund"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/cancelRefund"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizpayPostQuertAllOrderStatus : BaseITWebAPIBody {
	
	//
									open var orderType:String?
    		
	required public init(){
		super.init()
		self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/queryAllOrderStatus"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/queryAllOrderStatus"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let orderType_ = self.orderType;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("accessToken=" + (accessToken_ ?? ""))
																					
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizpayPostQuertAllOrderStatus",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"orderType",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:orderType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"orderType",body:self))
									result.append(vo.onFieldBegin(.flat,index:3,length:3,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:3,length:3,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:3,length:3,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"BizpayPostQuertAllOrderStatus",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizpayRetQueryAllOrderStatus : BaseITWebAPIBody {
	
	//
						open var successCode:String?
    										    		//----->list
			fileprivate var data = [BizpayOrderInfo]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/queryAllOrderStatus"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/queryAllOrderStatus"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		successCode = visitableSource.getValue("successCode")
																											retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( OrderInfo (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addData(subBody:OrderInfo) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [OrderInfo]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class BizpayOrderInfo : BaseITWebAPIBody {
	
	//
						open var orderId:String?
    							open var userId:String?
    							open var subject:String?
    							open var body:String?
    							open var orderNo:String?
    							open var orderStatus:String?
    							open var orderMoney:String?
    							open var orderType:String?
    							open var createTime:String?
    							open var paidTime:String?
    							open var refundedTime:String?
    							open var refundFlag:String?
    							open var posId:String?
    							open var carNum:String?
    		
	required public init(){
		super.init()
		self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/queryAllOrderStatus"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/queryAllOrderStatus"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		orderId = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("orderId"))
																											userId = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("userId"))
																											subject = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("subject"))
																											body = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("body"))
																											orderNo = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("orderNo"))
																											orderStatus = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("orderStatus"))
																											orderMoney = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("orderMoney"))
																											orderType = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("orderType"))
																											createTime = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("createTime"))
																											paidTime = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("paidTime"))
																											refundedTime = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("refundedTime"))
																											refundFlag = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("refundFlag"))
																											posId = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("posId"))
																											carNum = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("carNum"))
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class BizpayPostFinishOrder : BaseITWebAPIBody {
	
	//
									open var orderId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/finishOrder"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/finishOrder"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let orderId_ = self.orderId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizpayPostFinishOrder",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"orderId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:orderId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"orderId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizpayPostFinishOrder",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizpayRetFinishOrder : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/finishOrder"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/finishOrder"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class BizpayPostUpdateOrderCTime : BaseITWebAPIBody {
	
	//
									open var orderId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/updateOrderCTime"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/updateOrderCTime"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let accessToken_ = self.accessToken;
																					let orderId_ = self.orderId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"BizpayPostUpdateOrderCTime",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"accessToken",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:accessToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"accessToken",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"orderId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:orderId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"orderId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"BizpayPostUpdateOrderCTime",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class BizpayRetUpdateOrderCTime : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/updateOrderCTime"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "26"
		self.appName_ = "bizpay"
		self.mapping_ = "/api/bizpay/payment/updateOrderCTime"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
